@@ -1,222 +1,147 @@
-# coding: utf8
+# -*- coding: utf-8 -*-
 {
+'!langcode!': 'pt-br',
+'!langname!': 'Português Brasileiro',
 '"update" is an optional expression like "field1=\'newvalue\'". You cannot update or delete the results of a JOIN': '"update" é uma expressão opcional como "campo1=\'novo_valor\'". Não é permitido atualizar ou apagar resultados de um JOIN',
+'%s %%{row} deleted': '%s registros apagados',
+'%s %%{row} updated': '%s registros atualizados',
 '%Y-%m-%d': '%d/%m/%Y',
 '%Y-%m-%d %H:%M:%S': '%d/%m/%Y %H:%M:%S',
-'%s rows deleted': '%s registros apagados',
-'%s rows updated': '%s registros atualizados',
-'(requires internet access)': '(requer acesso a internet)',
+'(requires internet access, experimental)': '(requer acesso à internet, experimental)',
 '(something like "it-it")': '(algo como "it-it")',
+'@markmin\x01An error occured, please [[reload %s]] the page': 'An error occured, please [[reload %s]] the page',
+'@markmin\x01Searching: **%s** %%{file}': 'Buscando: **%s** arquivos',
 'A new version of web2py is available': 'Está disponível uma nova versão do web2py',
 'A new version of web2py is available: %s': 'Está disponível uma nova versão do web2py: %s',
-'ATTENTION: Login requires a secure (HTTPS) connection or running on localhost.': 'ATENÇÃO o login requer uma conexão segura (HTTPS) ou executar de localhost.',
-'ATTENTION: TESTING IS NOT THREAD SAFE SO DO NOT PERFORM MULTIPLE TESTS CONCURRENTLY.': 'ATENÇÃO OS TESTES NÃO THREAD SAFE, NÃO EFETUE MÚLTIPLOS TESTES AO MESMO TEMPO.',
-'ATTENTION: you cannot edit the running application!': 'ATENÇÃO: Não pode modificar a aplicação em execução!',
-'About': 'Sobre',
+'About': 'sobre',
 'About application': 'Sobre a aplicação',
-'Additional code for your application': 'Additional code for your application',
+'additional code for your application': 'código adicional para sua aplicação',
+'Additional code for your application': 'Código adicional para sua aplicação',
+'admin disabled because no admin password': ' admin desabilitado por falta de senha definida',
+'admin disabled because not supported on google app engine': 'admin desabilitado porque não é suportado no GAE',
+'admin disabled because unable to access password file': 'admin desabilitado porque não foi possível ler o arquivo de senha',
 'Admin is disabled because insecure channel': 'Admin desabilitado pois o canal não é seguro',
 'Admin is disabled because unsecure channel': 'Admin desabilitado pois o canal não é seguro',
-'Admin language': 'Linguagem do Admin',
-'Administrator Password:': 'Senha de administrador:',
-'Application name:': 'Nome da aplicação:',
-'Are you sure you want to delete file "%s"?': 'Tem certeza que deseja apagar o arquivo "%s"?',
-'Are you sure you want to delete plugin "%s"?': 'Tem certeza que deseja apagar o plugin "%s"?',
-'Are you sure you want to uninstall application "%s"': 'Tem certeza que deseja apagar a aplicação "%s"?',
-'Are you sure you want to uninstall application "%s"?': 'Tem certeza que deseja apagar a aplicação "%s"?',
-'Are you sure you want to upgrade web2py now?': 'Tem certeza que deseja atualizar o web2py agora?',
-'Available databases and tables': 'Bancos de dados e tabelas disponíveis',
-'Cannot be empty': 'Não pode ser vazio',
-'Cannot compile: there are errors in your app.        Debug it, correct errors and try again.': 'Não é possível compilar: Existem erros em sua aplicação.       Depure, corrija os errros e tente novamente',
-'Cannot compile: there are errors in your app:': 'Não é possível compilar: Existem erros em sua aplicação',
-'Change Password': 'Trocar Senha',
-'Check to delete': 'Marque para apagar',
-'Checking for upgrades...': 'Buscando atualizações...',
-'Click row to expand traceback': 'Clique em uma coluna para expandir o log do erro',
-'Client IP': 'IP do cliente',
-'Controllers': 'Controladores',
-'Count': 'Contagem',
-'Create new application using the Wizard': 'Criar nova aplicação utilizando o assistente',
-'Create new simple application': 'Crie uma nova aplicação',
-'Current request': 'Requisição atual',
-'Current response': 'Resposta atual',
-'Current session': 'Sessão atual',
-'DESIGN': 'Projeto',
-'Date and Time': 'Data e Hora',
-'Delete': 'Apague',
-'Delete:': 'Apague:',
-'Deploy on Google App Engine': 'Publicar no Google App Engine',
-'Description': 'Descrição',
-'Design for': 'Projeto de',
-'Detailed traceback description': 'Detailed traceback description',
-'E-mail': 'E-mail',
-'EDIT': 'EDITAR',
-'Edit Profile': 'Editar Perfil',
-'Edit application': 'Editar aplicação',
-'Edit current record': 'Editar o registro atual',
-'Editing Language file': 'Editando arquivo de linguagem',
-'Editing file': 'Editando arquivo',
-'Editing file "%s"': 'Editando arquivo "%s"',
-'Enterprise Web Framework': 'Framework web empresarial',
-'Error': 'Erro',
-'Error logs for "%(app)s"': 'Logs de erro para "%(app)s"',
-'Error snapshot': 'Error snapshot',
-'Error ticket': 'Error ticket',
-'Exception instance attributes': 'Atributos da instancia de excessão',
-'File': 'Arquivo',
-'First name': 'Nome',
-'Frames': 'Frames',
-'Functions with no doctests will result in [passed] tests.': 'Funções sem doctests resultarão em testes [aceitos].',
-'Group ID': 'ID do Grupo',
-'Hello World': 'Olá Mundo',
-'If the report above contains a ticket number it indicates a failure in executing the controller, before any attempt to execute the doctests. This is usually due to an indentation error or an error outside function code.\nA green title indicates that all tests (if defined) passed. In this case test results are not shown.': 'Se o relatório acima contém um número de ticket, isso indica uma falha no controlador em execução, antes de tantar executar os doctests. Isto acontece geralmente por erro de endentação ou erro fora do código da função.\nO titulo em verde indica que os testes (se definidos) passaram. Neste caso os testes não são mostrados.',
-'Import/Export': 'Importar/Exportar',
-'Installed applications': 'Aplicações instaladas',
-'Internal State': 'Estado Interno',
-'Invalid Query': 'Consulta inválida',
-'Invalid action': 'Ação inválida',
-'Invalid email': 'E-mail inválido',
-'Language files (static strings) updated': 'Arquivos de linguagem (textos estáticos) atualizados',
-'Languages': 'Linguagens',
-'Last name': 'Sobrenome',
-'Last saved on:': 'Salvo em:',
-'License for': 'Licença para',
-'Login': 'Entrar',
-'Login to the Administrative Interface': 'Entrar na interface adminitrativa',
-'Logout': 'Sair',
-'Lost Password': 'Senha perdida',
-'Models': 'Modelos',
-'Modules': 'Módulos',
-'NO': 'NÃO',
-'Name': 'Nome',
-'New Record': 'Novo registro',
-'New application wizard': 'Assistente para novas aplicações ',
-'New simple application': 'Nova aplicação básica',
-'No databases in this application': 'Não existem bancos de dados nesta aplicação',
-'Origin': 'Origem',
-'Original/Translation': 'Original/Tradução',
-'PAM authenticated user, cannot change password here': 'usuario autenticado por PAM, não pode alterar a senha por aqui',
-'Password': 'Senha',
-'Peeking at file': 'Visualizando arquivo',
-'Plugin "%s" in application': 'Plugin "%s" na aplicação',
-'Plugins': 'Plugins',
-'Powered by': 'Este site utiliza',
-'Query:': 'Consulta:',
-'Record ID': 'ID do Registro',
-'Register': 'Registrar-se',
-'Registration key': 'Chave de registro',
-'Resolve Conflict file': 'Arquivo de resolução de conflito',
-'Role': 'Papel',
-'Rows in table': 'Registros na tabela',
-'Rows selected': 'Registros selecionados',
-'Saved file hash:': 'Hash do arquivo salvo:',
-'Searching:': 'Searching:',
-'Static files': 'Arquivos estáticos',
-'Sure you want to delete this object?': 'Tem certeza que deseja apaagr este objeto?',
-'TM': 'MR',
-'Table name': 'Nome da tabela',
-'Testing application': 'Testando a aplicação',
-'The "query" is a condition like "db.table1.field1==\'value\'". Something like "db.table1.field1==db.table2.field2" results in a SQL JOIN.': 'A "consulta" é uma condição como "db.tabela.campo1==\'valor\'". Algo como "db.tabela1.campo1==db.tabela2.campo2" resulta em um JOIN SQL.',
-'The application logic, each URL path is mapped in one exposed function in the controller': 'The application logic, each URL path is mapped in one exposed function in the controller',
-'The data representation, define database tables and sets': 'The data representation, define database tables and sets',
-'The presentations layer, views are also known as templates': 'The presentations layer, views are also known as templates',
-'There are no controllers': 'Não existem controllers',
-'There are no models': 'Não existem modelos',
-'There are no modules': 'Não existem módulos',
-'There are no plugins': 'There are no plugins',
-'There are no static files': 'Não existem arquicos estáticos',
-'There are no translators, only default language is supported': 'Não há traduções, somente a linguagem padrão é suportada',
-'There are no views': 'Não existem visões',
-'These files are served without processing, your images go here': 'These files are served without processing, your images go here',
-'This is the %(filename)s template': 'Este é o template %(filename)s',
-'Ticket': 'Ticket',
-'Ticket ID': 'Ticket ID',
-'Timestamp': 'Data Atual',
-'To create a plugin, name a file/folder plugin_[name]': 'Para criar um plugin, nomeio um arquivo/pasta como plugin_[nome]',
-'Traceback': 'Traceback',
-'Translation strings for the application': 'Translation strings for the application',
-'Unable to check for upgrades': 'Não é possível checar as atualizações',
-'Unable to download': 'Não é possível efetuar o download',
-'Unable to download app': 'Não é possível baixar a aplicação',
-'Unable to download app because:': 'Não é possível baixar a aplicação porque:',
-'Unable to download because': 'Não é possível baixar porque',
-'Update:': 'Atualizar:',
-'Upload & install packed application': 'Faça upload e instale uma aplicação empacotada',
-'Upload a package:': 'Faça upload de um pacote:',
-'Upload existing application': 'Faça upload de uma aplicação existente',
-'Use (...)&(...) for AND, (...)|(...) for OR, and ~(...)  for NOT to build more complex queries.': 'Use (...)&(...) para AND, (...)|(...) para OR, y ~(...) para NOT, para criar consultas mais complexas.',
-'Use an url:': 'Use uma url:',
-'User ID': 'ID do Usuario',
-'Version': 'Versão',
-'Views': 'Visões',
-'Welcome to web2py': 'Bem-vindo ao web2py',
-'YES': 'SIM',
-'About': 'sobre',
-'additional code for your application': 'código adicional para sua aplicação',
-'admin disabled because no admin password': ' admin desabilitado por falta de senha definida',
-'admin disabled because not supported on google app engine': 'admin dehabilitado, não é soportado no GAE',
-'admin disabled because unable to access password file': 'admin desabilitado, não foi possível ler o arquivo de senha',
+'Admin language': 'Idioma do Admin',
 'administrative interface': 'interface administrativa',
+'Administrator Password:': 'Senha de administrador:',
 'and rename it (required):': 'e renomeie (requerido):',
 'and rename it:': ' e renomeie:',
 'appadmin': 'appadmin',
-'appadmin is disabled because insecure channel': 'admin desabilitado, canal inseguro',
+'appadmin is disabled because insecure channel': 'admin desabilitado porque o canal não é seguro',
 'application "%s" uninstalled': 'aplicação "%s" desinstalada',
 'application compiled': 'aplicação compilada',
 'application is compiled and cannot be designed': 'A aplicação está compilada e não pode ser modificada',
+'Application name:': 'Nome da aplicação:',
+'Are you sure you want to delete file "%s"?': 'Tem certeza que deseja apagar o arquivo "%s"?',
+'Are you sure you want to delete plugin "%s"?': 'Tem certeza que deseja apagar o plugin "%s"?',
+'Are you sure you want to delete this object?': 'Tem certeza que deseja apagar esse objeto?',
+'Are you sure you want to uninstall application "%s"': 'Tem certeza que deseja desinstalar a aplicação "%s"?',
+'Are you sure you want to uninstall application "%s"?': 'Tem certeza que deseja desinstalar a aplicação "%s"?',
+'Are you sure you want to upgrade web2py now?': 'Tem certeza que deseja atualizar o web2py agora?',
 'arguments': 'argumentos',
+'ATTENTION: Login requires a secure (HTTPS) connection or running on localhost.': 'ATENÇÃO: o login requer uma conexão segura (HTTPS) ou executar de localhost.',
+'ATTENTION: TESTING IS NOT THREAD SAFE SO DO NOT PERFORM MULTIPLE TESTS CONCURRENTLY.': 'ATENÇÃO OS TESTES NÃO SÃO THREAD SAFE, NÃO EFETUE MÚLTIPLOS TESTES AO MESMO TEMPO.',
+'ATTENTION: you cannot edit the running application!': 'ATENÇÃO: Não pode modificar a aplicação em execução!',
+'Available databases and tables': 'Bancos de dados e tabelas disponíveis',
 'back': 'voltar',
-'browse': 'buscar',
+'Basics': 'Informações básicas',
+'Begin': 'Iniciar',
+'browse': 'navegar',
 'cache': 'cache',
 'cache, errors and sessions cleaned': 'cache, erros e sessões eliminadas',
+'can be a git repo': 'pode ser um repositório git',
+'Cannot be empty': 'Não pode ser vazio',
+'Cannot compile: there are errors in your app.        Debug it, correct errors and try again.': 'Não é possível compilar: Existem erros em sua aplicação.       Depure, corrija os errros e tente novamente',
+'Cannot compile: there are errors in your app:': 'Não é possível compilar: Existem erros em sua aplicação',
 'cannot create file': 'Não é possível criar o arquivo',
 'cannot upload file "%(filename)s"': 'não é possível fazer upload do arquivo "%(filename)s"',
 'Change admin password': 'mudar senha de administrador',
+'Change Password': 'Mudar Senha',
 'check all': 'marcar todos',
-'Check for upgrades': 'checar por atualizações',
-'Clean': 'limpar',
+'Check for upgrades': 'Verificar se existem atualizações',
+'Check to delete': 'Marque para apagar',
+'Checking for upgrades...': 'Buscando atualizações...',
+'Clean': 'Limpo',
 'click here for online examples': 'clique para ver exemplos online',
 'click here for the administrative interface': 'Clique aqui para acessar a interface administrativa',
-'click to check for upgrades': 'clique aqui para checar por atualizações',
+'Click row to expand traceback': 'Clique na linha para expandir o traceback',
+'click to check for upgrades': 'clique aqui para verificar se existem atualizações',
 'click to open': 'clique para abrir',
+'Client IP': 'IP do cliente',
 'code': 'código',
-'collapse/expand all': 'collapse/expand all',
+'collapse/expand all': 'fechar/abrir todos',
 'commit (mercurial)': 'commit (mercurial)',
-'Compile': 'compilar',
-'compiled application removed': 'aplicação compilada removida',
+'Compile': 'Compilar',
+'compiled application removed': 'a aplicação compilada foi removida',
+'Controllers': 'Controladores',
 'controllers': 'controladores',
-'Create': 'criar',
+'Count': 'Contagem',
+'Create': 'Criar',
 'create file with filename:': 'criar um arquivo com o nome:',
+'Create new application using the Wizard': 'Criar nova aplicação utilizando o Assistente',
 'create new application:': 'nome da nova aplicação:',
+'Create new simple application': 'Crie uma nova aplicação',
 'created by': 'criado por',
 'crontab': 'crontab',
+'Current request': 'Requisição atual',
+'Current response': 'Resposta atual',
+'Current session': 'Sessão atual',
 'currently running': 'Executando',
 'currently saved or': 'Atualmente salvo ou',
-'customize me!': 'Modifique-me',
+'customize me!': 'Modifique-me!',
 'data uploaded': 'Dados enviados',
 'database': 'banco de dados',
-'database %s select': 'Seleção no banco de dados %s',
-'database administration': 'administração de banco de dados',
+'database %s select': 'Select no banco de dados %s',
+'database administration': 'administração do banco de dados',
+'Date and Time': 'Data e Hora',
 'db': 'db',
+'Debug': 'Debug',
 'defines tables': 'define as tabelas',
+'Delete': 'Apague',
 'delete': 'apagar',
 'delete all checked': 'apagar marcados',
 'delete plugin': 'apagar plugin',
-'Deploy': 'publicar',
-'design': 'modificar',
+'Delete:': 'Apague:',
+'Deploy': 'Publicar',
+'Deploy on Google App Engine': 'Publicar no Google App Engine',
+'Deploy to OpenShift': 'Publicar no OpenShift',
+'Description': 'Descrição',
+'design': 'projeto',
+'DESIGN': 'Projeto',
+'Design for': 'Projeto de',
+'Detailed traceback description': 'Descrição detalhada do traceback',
 'direction: ltr': 'direção: ltr',
+'Disable': 'Desabilitar',
 'done!': 'feito!',
-'download layouts': 'download layouts',
-'download plugins': 'download plugins',
-'Edit': 'editar',
+'Download .w2p': 'Download .w2p',
+'download layouts': 'download de layouts',
+'download plugins': 'download de plugins',
+'E-mail': 'E-mail',
+'EDIT': 'EDITAR',
+'Edit': 'Editar',
+'edit all': 'editar todos',
+'Edit application': 'Editar aplicação',
 'edit controller': 'editar controlador',
+'Edit current record': 'Editar o registro atual',
+'Edit Profile': 'Editar Perfil',
 'edit views:': 'editar visões:',
-'Errors': 'erros',
+'Editing file': 'Editando arquivo',
+'Editing file "%s"': 'Editando arquivo "%s"',
+'Editing Language file': 'Editando arquivo de idioma',
+'Enterprise Web Framework': 'Framework Web Corporativo',
+'Error': 'Erro',
+'Error logs for "%(app)s"': 'Logs de erro para "%(app)s"',
+'Error snapshot': 'Momento do Erro',
+'Error ticket': 'Tiquete de Erro',
+'Errors': 'Erros',
+'Exception instance attributes': 'Atributos de instância da Exception',
 'export as csv file': 'exportar como arquivo CSV',
 'exposes': 'expõe',
 'extends': 'estende',
 'failed to reload module': 'Falha ao recarregar o módulo',
-'failed to reload module because:': 'falha ao recarregar o módulo por:',
+'failed to reload module because:': 'falha ao recarregar o módulo porque:',
+'File': 'Arquivo',
 'file "%(filename)s" created': 'arquivo "%(filename)s" criado',
 'file "%(filename)s" deleted': 'arquivo "%(filename)s" apagado',
 'file "%(filename)s" uploaded': 'arquivo "%(filename)s" enviado',
@@ -226,97 +151,198 @@
 'file does not exist': 'arquivo não existe',
 'file saved on %(time)s': 'arquivo salvo em %(time)s',
 'file saved on %s': 'arquivo salvo em %s',
-'files': 'files',
-'filter': 'filter',
-'Help': 'ajuda',
+'filter': 'filtro',
+'First name': 'Nome',
+'Frames': 'Frames',
+'Functions with no doctests will result in [passed] tests.': 'Funções sem doctests resultarão em testes [aceitos].',
+'Generate': 'Gerar',
+'go!': 'vai!',
+'Group ID': 'ID do Grupo',
+'Hello World': 'Olá Mundo',
+'Help': 'Ajuda',
 'htmledit': 'htmledit',
+'If the report above contains a ticket number it indicates a failure in executing the controller, before any attempt to execute the doctests. This is usually due to an indentation error or an error outside function code.\nA green title indicates that all tests (if defined) passed. In this case test results are not shown.': 'Se o relatório acima contém um número de ticket, isso indica uma falha no controlador em execução, antes de tentar executar os doctests. Isto acontece geralmente por erro de identação ou um erro fora do código da função.\nO título em verde indica que os testes (se definidos) passaram. Neste caso o resultado dos testes não são mostrados.',
+'Import/Export': 'Importar/Exportar',
 'includes': 'inclui',
 'insert new': 'inserir novo',
 'insert new %s': 'inserir novo %s',
-'inspect attributes': 'inspect attributes',
+'inspect attributes': 'inspeciona atributos',
 'Install': 'instalar',
+'Installed applications': 'Aplicações instaladas',
 'internal error': 'erro interno',
+'Internal State': 'Estado Interno',
+'Invalid action': 'Ação inválida',
+'Invalid email': 'E-mail inválido',
 'invalid password': 'senha inválida',
+'Invalid Query': 'Consulta inválida',
 'invalid request': 'solicitação inválida',
 'invalid ticket': 'ticket inválido',
-'language file "%(filename)s" created/updated': 'arquivo de linguagem "%(filename)s" criado/atualizado',
-'languages': 'linguagens',
-'languages updated': 'linguagens atualizadas',
+'language file "%(filename)s" created/updated': 'arquivo de idioma "%(filename)s" criado/atualizado',
+'Language files (static strings) updated': 'Arquivos de idioma (textos estáticos) atualizados',
+'languages': 'idiomas',
+'Languages': 'Idiomas',
+'languages updated': 'idiomas atualizados',
+'Last name': 'Sobrenome',
+'Last saved on:': 'Salvo pela última vez em:',
+'License for': 'Licença para',
 'loading...': 'carregando...',
 'locals': 'locals',
-'login': 'inicio de sessão',
+'Login': 'Entrar',
+'login': 'início de sessão',
+'Login to the Administrative Interface': 'Entrar na interface adminitrativa',
 'Logout': 'finalizar sessão',
+'Lost Password': 'Perdi a senha',
+'Manage': 'Gerenciar',
 'manage': 'gerenciar',
 'merge': 'juntar',
+'Models': 'Modelos',
 'models': 'modelos',
+'Modules': 'Módulos',
 'modules': 'módulos',
+'Name': 'Nome',
 'new application "%s" created': 'nova aplicação "%s" criada',
+'New Application Wizard': 'Assistente para novas aplicações ',
+'New application wizard': 'Assistente para novas aplicações',
 'new plugin installed': 'novo plugin instalado',
+'New Record': 'Novo registro',
 'new record inserted': 'novo registro inserido',
+'New simple application': 'Nova aplicação básica',
 'next 100 rows': 'próximos 100 registros',
+'NO': 'NÃO',
+'No databases in this application': 'Não existem bancos de dados nesta aplicação',
 'no match': 'não encontrado',
+'no package selected': 'nenhum pacote selecionado',
+'Or Get from URL:': 'Ou baixa da URL:',
 'or import from csv file': 'ou importar de um arquivo CSV',
 'or provide app url:': 'ou forneça a url de uma aplicação:',
 'or provide application url:': 'ou forneça a url de uma aplicação:',
-'Overwrite installed app': 'sobrescrever aplicação instalada',
-'Pack all': 'criar pacote',
-'Pack compiled': 'criar pacote compilado',
+'Origin': 'Origem',
+'Original/Translation': 'Original/Tradução',
+'Overwrite installed app': 'Sobrescrever aplicação instalada',
+'Pack all': 'Criar pacote',
+'Pack compiled': 'Criar pacote compilado',
+'Pack custom': 'Customizar pacote',
 'pack plugin': 'empacotar plugin',
+'PAM authenticated user, cannot change password here': 'usuário autenticado por PAM não pode alterar a senha aqui',
+'Password': 'Senha',
 'password changed': 'senha alterada',
-'plugin "%(plugin)s" deleted': 'plugin "%(plugin)s" eliminado',
+'Peeking at file': 'Visualizando arquivo',
+'plugin "%(plugin)s" deleted': 'plugin "%(plugin)s" apagado',
+'Plugin "%s" in application': 'Plugin "%s" na aplicação',
 'plugins': 'plugins',
+'Plugins': 'Plugins',
+'Powered by': 'Este site utiliza',
 'previous 100 rows': '100 registros anteriores',
+'Query:': 'Consulta:',
 'record': 'registro',
 'record does not exist': 'o registro não existe',
 'record id': 'id do registro',
-'Remove compiled': 'eliminar compilados',
+'Record ID': 'ID do Registro',
+'Register': 'Registrar-se',
+'Registration key': 'Chave de registro',
+'Reload routes': 'Recarregar routes',
+'Remove compiled': 'Eliminar compilados',
 'request': 'request',
+'Resolve Conflict file': 'Arquivo de resolução de conflito',
 'response': 'response',
+'restart': 'reiniciar',
 'restore': 'restaurar',
 'revert': 'reverter',
+'Role': 'Papel',
+'Rows in table': 'Registros na tabela',
+'Rows selected': 'Registros selecionados',
+'Running on %s': 'Rodando em %s',
 'save': 'salvar',
+'Saved file hash:': 'Hash do arquivo salvo:',
+'Select Files to Package': 'Selecione arquivos para empacotar',
 'selected': 'selecionado(s)',
 'session': 'session',
 'session expired': 'sessão expirada',
 'shell': 'Terminal',
-'Site': 'site',
-'some files could not be removed': 'alguns arquicos não puderam ser removidos',
-'Start wizard': 'iniciar assistente',
+'Site': 'Site',
+'skip to generate': 'pular para a gerar a aplicação',
+'some files could not be removed': 'alguns arquivos não puderam ser removidos',
+'Start a new app': 'Inicie uma nova aplicação',
+'Start wizard': 'Iniciar assistente',
 'state': 'estado',
 'static': 'estáticos',
+'Static files': 'Arquivos estáticos',
+'Step': 'Passo',
+'Submit': 'Enviar',
 'submit': 'enviar',
+'Sure you want to delete this object?': 'Tem certeza que deseja apagar este objeto?',
 'table': 'tabela',
+'Table name': 'Nome da tabela',
 'test': 'testar',
+'Testing application': 'Testando a aplicação',
+'The "query" is a condition like "db.table1.field1==\'value\'". Something like "db.table1.field1==db.table2.field2" results in a SQL JOIN.': 'A "consulta" é uma condição como "db.tabela.campo1==\'valor\'". Algo como "db.tabela1.campo1==db.tabela2.campo2" resulta em um JOIN SQL.',
 'the application logic, each URL path is mapped in one exposed function in the controller': 'A lógica da aplicação, cada URL é mapeada para uma função exposta pelo controlador',
-'the data representation, define database tables and sets': 'A representação dos dadps, define tabelas e estruturas de dados',
-'the presentations layer, views are also known as templates': 'A camada de apresentação, As visões também são chamadas de templates',
+'The application logic, each URL path is mapped in one exposed function in the controller': 'A lógica da aplicação, cada URL é mapeada para uma função exposta pelo controlador',
+'the data representation, define database tables and sets': 'A representação dos dados, define tabelas do banco de dados e conjuntos',
+'The data representation, define database tables and sets': 'A representação dos dados, define tabelas do banco de dados e conjuntos',
+'The presentations layer, views are also known as templates': 'A camada de apresentação, as visões também são chamadas de templates',
+'the presentations layer, views are also known as templates': 'A camada de apresentação, as visões também são chamadas de templates',
+'There are no controllers': 'Não existem controladores',
+'There are no models': 'Não existem modelos',
+'There are no modules': 'Não existem módulos',
+'There are no plugins': 'Não existem plugins',
+'There are no static files': 'Não existem arquicos estáticos',
+'There are no translators, only default language is supported': 'Não há tradutores, somente a linguagem padrão é suportada',
+'There are no views': 'Não existem visões',
+'These files are served without processing, your images go here': 'Estes arquivos são servidos sem processamento, suas imagens ficam aqui',
 'these files are served without processing, your images go here': 'Estes arquivos são servidos sem processamento, suas imagens ficam aqui',
+'This is the %(filename)s template': 'Este é o template %(filename)s',
+'Ticket': 'Ticket',
+'Ticket ID': 'Número do Ticket',
+'Timestamp': 'Momento de geração',
+'TM': 'MR',
 'to  previous version.': 'para a versão anterior.',
+'To create a plugin, name a file/folder plugin_[name]': 'Para criar um plugin, nomeie um arquivo/pasta como plugin_[nome]',
+'Traceback': 'Traceback',
 'translation strings for the application': 'textos traduzidos para a aplicação',
+'Translation strings for the application': 'textos traduzidos para a aplicação',
 'try': 'tente',
 'try something like': 'tente algo como',
+'Try the mobile interface': 'Experimente a interface para smartphones e tablets',
+'Unable to check for upgrades': 'Não é possível checar as atualizações',
 'unable to create application "%s"': 'não é possível criar a aplicação "%s"',
-'unable to delete file "%(filename)s"': 'não é possível criar o arquico "%(filename)s"',
+'unable to delete file "%(filename)s"': 'não é possível criar o arquivo "%(filename)s"',
 'unable to delete file plugin "%(plugin)s"': 'não é possível criar o plugin "%(plugin)s"',
+'Unable to download': 'Não é possível efetuar o download',
+'Unable to download app': 'Não é possível baixar a aplicação',
+'Unable to download app because:': 'Não é possível baixar a aplicação porque:',
+'Unable to download because': 'Não é possível baixar porque',
 'unable to parse csv file': 'não é possível analisar o arquivo CSV',
-'unable to uninstall "%s"': 'não é possível instalar "%s"',
+'unable to uninstall "%s"': 'não é possível desinstalar "%s"',
 'unable to upgrade because "%s"': 'não é possível atualizar porque "%s"',
 'uncheck all': 'desmarcar todos',
-'Uninstall': 'desinstalar',
-'update': 'atualizar',
-'update all languages': 'atualizar todas as linguagens',
+'Uninstall': 'Desinstalar',
+'update': 'alterar',
+'update all languages': 'alterar todos os idiomas',
+'Update:': 'Alterar:',
+'upgrade now to %s': 'Atualize agora para %s',
 'upgrade web2py now': 'atualize o web2py agora',
 'upload': 'upload',
+'Upload a package:': 'Faça upload de um pacote:',
+'Upload and install packed application': 'Faça upload e instale uma aplicação empacotada',
 'upload application:': 'Fazer upload de uma aplicação:',
+'Upload existing application': 'Faça upload de uma aplicação existente',
 'upload file:': 'Enviar arquivo:',
 'upload plugin file:': 'Enviar arquivo de plugin:',
+'Use (...)&(...) for AND, (...)|(...) for OR, and ~(...)  for NOT to build more complex queries.': 'Use (...)&(...) para AND, (...)|(...) para OR, e ~(...) para NOT, para criar consultas mais complexas.',
+'Use an url:': 'Use uma url:',
+'User ID': 'ID do Usuário',
 'variables': 'variáveis',
+'Version': 'Versão',
 'versioning': 'versionamento',
+'Versioning': 'Versionamento',
 'view': 'visão',
+'Views': 'Visões',
 'views': 'visões',
-'web2py Recent Tweets': 'Tweets Recentes de @web2py',
+'Web Framework': 'Web Framework',
 'web2py is up to date': 'web2py está atualizado',
+'web2py Recent Tweets': 'Tweets Recentes de @web2py',
 'web2py upgraded; please restart it': 'web2py atualizado; favor reiniciar',
+'Welcome to web2py': 'Bem-vindo ao web2py',
+'YES': 'SIM',
 }
-
-
