@@ -1,15 +1,17 @@
-# coding: utf8
+# -*- coding: utf-8 -*-
 {
+'!langcode!': 'sl',
+'!langname!': 'Slovenski',
 '"update" is an optional expression like "field1=\'newvalue\'". You cannot update or delete the results of a JOIN': '"Popravi" je izbirni izraz kot npr.: "stolpec1 = \'novavrednost\'". Rezultatov JOIN operacije ne morete popravljati ali brisati',
 '%Y-%m-%d': '%Y-%m-%d',
 '%Y-%m-%d %H:%M:%S': '%Y-%m-%d %H:%M:%S',
-'%s rows deleted': '%s vrstic izbrisanih',
-'%s rows updated': '%s vrstic popravljeno',
+'%s %%{row} deleted': '%s vrstic izbrisanih',
+'%s %%{row} updated': '%s vrstic popravljeno',
 '(requires internet access)': '(zahteva internetni dostop)',
 '(something like "it-it")': '(nekaj kot "sl-SI" ali samo "sl")',
+'@markmin\x01Searching: **%s** %%{file}': 'Iskanje: **%s** datoteke',
 'A new version of web2py is available': 'Nova različica web2py je na voljo',
 'A new version of web2py is available: %s': 'Nova različica web2py je na voljo: %s',
-'A new version of web2py is available: Version 1.85.3 (2010-09-18 07:07:46)\n': 'Nova različica web2py je na voljo: Različica 1.85.3 (2010-09-18 07:07:46)\n',
 'ATTENTION: Login requires a secure (HTTPS) connection or running on localhost.': 'POZOR: Prijava zahteva varno povezavo (HTTPS) ali lokalni (localhost) dostop.',
 'ATTENTION: TESTING IS NOT THREAD SAFE SO DO NOT PERFORM MULTIPLE TESTS CONCURRENTLY.': 'POZOR: Testiranje ni večopravilno, zato ne poganjajte več testov hkrati.',
 'ATTENTION: This is an experimental feature and it needs more testing.': 'POZOR: To je preizkusni fazi in potrebuje več testiranja.',
@@ -154,7 +156,6 @@
 "Run tests in this file (to run all files, you may also use the button labelled 'test')": "Poženi teste v tej datoteki (za vse teste uporabite gumb 'test')",
 'Save via Ajax': 'Shrani preko AJAX',
 'Saved file hash:': 'Koda shranjene datoteke:',
-'Searching:': 'Iskanje:',
 'Site': 'Spletišče',
 'Sorry, could not find mercurial installed': 'Oprostite. Mercurial ni nameščen.',
 'Start a new app': 'Začnite z novo aplikacijo',
@@ -281,7 +282,6 @@
 'file does not exist': 'datoteka ne obstaja',
 'file saved on %(time)s': 'datoteka shranjena %(time)s',
 'file saved on %s': 'datoteka shranjena %s',
-'files': 'datoteke',
 'filter': 'fiter',
 'htmledit': 'htmledit',
 'includes': 'vključuje',
