@@ -1,41 +1,69 @@
 # coding: utf8
 {
+'!langcode!': 'fr-ca',
+'!langname!': 'Français (Canadien)',
 '"update" is an optional expression like "field1=\'newvalue\'". You cannot update or delete the results of a JOIN': '"update" est une expression optionnelle comme "champ1=\'nouvellevaleur\'". Vous ne pouvez mettre à jour ou supprimer les résultats d\'un JOIN',
+'%s %%{row} deleted': '%s rangées supprimées',
+'%s %%{row} updated': '%s rangées mises à jour',
+'%s selected': '%s sélectionné',
 '%Y-%m-%d': '%Y-%m-%d',
 '%Y-%m-%d %H:%M:%S': '%Y-%m-%d %H:%M:%S',
-'%s rows deleted': '%s rangées supprimées',
-'%s rows updated': '%s rangées mises à jour',
+'about': 'à propos',
 'About': 'À propos',
 'Access Control': "Contrôle d'accès",
+'Administrative Interface': 'Administrative Interface',
 'Administrative interface': "Interface d'administration",
 'Ajax Recipes': 'Recettes Ajax',
+'appadmin is disabled because insecure channel': "appadmin est désactivée parce que le canal n'est pas sécurisé",
 'Are you sure you want to delete this object?': 'Êtes-vous sûr de vouloir supprimer cet objet?',
 'Authentication': 'Authentification',
-'Available databases and tables': 'Bases de données et tables disponibles',
+'Available Databases and Tables': 'Bases de données et tables disponibles',
 'Buy this book': 'Acheter ce livre',
+'cache': 'cache',
+'Cache': 'Cache',
+'Cache Keys': 'Cache Keys',
 'Cannot be empty': 'Ne peut pas être vide',
+'change password': 'changer le mot de passe',
 'Check to delete': 'Cliquez pour supprimer',
 'Check to delete:': 'Cliquez pour supprimer:',
+'Clear CACHE?': 'Clear CACHE?',
+'Clear DISK': 'Clear DISK',
+'Clear RAM': 'Clear RAM',
 'Client IP': 'IP client',
 'Community': 'Communauté',
+'Components and Plugins': 'Components and Plugins',
 'Controller': 'Contrôleur',
 'Copyright': "Droit d'auteur",
 'Current request': 'Demande actuelle',
 'Current response': 'Réponse actuelle',
 'Current session': 'Session en cours',
+'customize me!': 'personnalisez-moi!',
+'data uploaded': 'données téléchargées',
+'Database': 'base de données',
+'Database %s select': 'base de données %s select',
+'db': 'db',
 'DB Model': 'Modèle DB',
-'Database': 'Base de données',
 'Delete:': 'Supprimer:',
 'Demo': 'Démo',
 'Deployment Recipes': 'Recettes de déploiement ',
 'Description': 'Descriptif',
+'design': 'design',
+'DISK': 'DISK',
+'Disk Cache Keys': 'Disk Cache Keys',
+'Disk Cleared': 'Disk Cleared',
 'Documentation': 'Documentation',
+"Don't know what to do?": "Don't know what to do?",
+'done!': 'fait!',
 'Download': 'Téléchargement',
 'E-mail': 'Courriel',
 'Edit': 'Éditer',
-'Edit This App': 'Modifier cette application',
 'Edit current record': "Modifier l'enregistrement courant",
+'edit profile': 'modifier le profil',
+'Edit This App': 'Modifier cette application',
+'Email and SMS': 'Email and SMS',
+'enter an integer between %(min)g and %(max)g': 'entrer un entier compris entre %(min)g et %(max)g',
 'Errors': 'Erreurs',
+'export as csv file': 'exporter sous forme de fichier csv',
 'FAQ': 'faq',
 'First name': 'Prénom',
 'Forms and Validators': 'Formulaires et Validateurs',
@@ -47,44 +75,73 @@
 'Groups': 'Groupes',
 'Hello World': 'Bonjour le monde',
 'Home': 'Accueil',
+'How did you get here?': 'How did you get here?',
+'import': 'import',
 'Import/Export': 'Importer/Exporter',
 'Index': 'Index',
+'insert new': 'insérer un nouveau',
+'insert new %s': 'insérer un nouveau %s',
 'Internal State': 'État interne',
 'Introduction': 'Présentation',
-'Invalid Query': 'Requête Invalide',
 'Invalid email': 'Courriel invalide',
+'Invalid Query': 'Requête Invalide',
+'invalid request': 'requête invalide',
+'Key': 'Key',
 'Last name': 'Nom',
 'Layout': 'Mise en page',
+'Layout Plugins': 'Layout Plugins',
 'Layouts': 'layouts',
 'Live chat': 'Clavardage en direct',
+'Live Chat': 'Live Chat',
 'Logged in': 'Connecté',
+'login': 'connectez-vous',
 'Login': 'Connectez-vous',
+'logout': 'déconnectez-vous',
+'lost password': 'mot de passe perdu',
 'Lost Password': 'Mot de passe perdu',
+'lost password?': 'mot de passe perdu?',
 'Main Menu': 'Menu principal',
+'Manage Cache': 'Manage Cache',
 'Menu Model': 'Menu modèle',
+'My Sites': 'My Sites',
 'Name': 'Nom',
 'New Record': 'Nouvel enregistrement',
+'new record inserted': 'nouvel enregistrement inséré',
+'next 100 rows': '100 prochaines lignes',
 'No databases in this application': "Cette application n'a pas de bases de données",
 'Online examples': 'Exemples en ligne',
+'or import from csv file': "ou importer d'un fichier CSV",
 'Origin': 'Origine',
+'Other Plugins': 'Other Plugins',
 'Other Recipes': 'Autres recettes',
 'Overview': 'Présentation',
+'password': 'mot de passe',
 'Password': 'Mot de passe',
 "Password fields don't match": 'Les mots de passe ne correspondent pas',
+'please input your password again': "S'il vous plaît entrer votre mot de passe",
 'Plugins': 'Plugiciels',
 'Powered by': 'Alimenté par',
 'Preface': 'Préface',
+'previous 100 rows': '100 lignes précédentes',
+'profile': 'profile',
 'Python': 'Python',
 'Query:': 'Requête:',
 'Quick Examples': 'Examples Rapides',
+'RAM': 'RAM',
+'RAM Cache Keys': 'RAM Cache Keys',
+'Ram Cleared': 'Ram Cleared',
 'Readme': 'Lisez-moi',
 'Recipes': 'Recettes',
+'Record': 'enregistrement',
 'Record %(id)s created': 'Record %(id)s created',
 'Record %(id)s updated': 'Record %(id)s updated',
 'Record Created': 'Record Created',
+'record does not exist': "l'archive n'existe pas",
 'Record ID': "ID d'enregistrement",
+'Record id': "id d'enregistrement",
 'Record Updated': 'Record Updated',
 'Register': "S'inscrire",
+'register': "s'inscrire",
 'Registration key': "Clé d'enregistrement",
 'Registration successful': 'Inscription réussie',
 'Remember me (for 30 days)': 'Se souvenir de moi (pendant 30 jours)',
@@ -92,29 +149,37 @@
 'Reset Password key': 'Réinitialiser le mot clé',
 'Resources': 'Ressources',
 'Role': 'Rôle',
-'Rows in table': 'Lignes du tableau',
+'Rows in Table': 'Lignes du tableau',
 'Rows selected': 'Lignes sélectionnées',
 'Semantic': 'Sémantique',
 'Services': 'Services',
+'Size of cache:': 'Size of cache:',
+'state': 'état',
+'Statistics': 'Statistics',
 'Stylesheet': 'Feuille de style',
+'submit': 'submit',
 'Submit': 'Soumettre',
 'Support': 'Soutien',
 'Sure you want to delete this object?': 'Êtes-vous sûr de vouloir supprimer cet objet?',
+'Table': 'tableau',
 'Table name': 'Nom du tableau',
 'The "query" is a condition like "db.table1.field1==\'value\'". Something like "db.table1.field1==db.table2.field2" results in a SQL JOIN.': 'La "query" est une condition comme "db.table1.champ1==\'valeur\'". Quelque chose comme "db.table1.champ1==db.table2.champ2" résulte en un JOIN SQL.',
 'The Core': 'Le noyau',
+'The output of the file is a dictionary that was rendered by the view %s': 'La sortie de ce fichier est un dictionnaire qui été restitué par la vue %s',
 'The Views': 'Les Vues',
-'The output of the file is a dictionary that was rendered by the view': 'La sortie de ce fichier est un dictionnaire qui été restitué par la vue',
 'This App': 'Cette Appli',
 'This is a copy of the scaffolding application': "Ceci est une copie de l'application échafaudage",
+'Time in Cache (h:m:s)': 'Time in Cache (h:m:s)',
 'Timestamp': 'Horodatage',
 'Twitter': 'Twitter',
+'unable to parse csv file': "incapable d'analyser le fichier cvs",
 'Update:': 'Mise à jour:',
 'Use (...)&(...) for AND, (...)|(...) for OR, and ~(...)  for NOT to build more complex queries.': 'Employez (...)&(...) pour AND, (...)|(...) pour OR, and ~(...)  pour NOT pour construire des requêtes plus complexes.',
 'User %(id)s Logged-in': 'Utilisateur %(id)s connecté',
 'User %(id)s Registered': 'Utilisateur %(id)s enregistré',
 'User ID': 'ID utilisateur',
 'User Voice': 'User Voice',
+'value already in database or empty': 'valeur déjà dans la base ou vide',
 'Verify Password': 'Vérifiez le mot de passe',
 'Videos': 'Vidéos',
 'View': 'Présentation',
@@ -122,47 +187,9 @@
 'Welcome': 'Bienvenu',
 'Welcome %s': 'Bienvenue %s',
 'Welcome to web2py': 'Bienvenue à web2py',
-'Which called the function': 'Qui a appelé la fonction',
+'Welcome to web2py!': 'Welcome to web2py!',
+'Which called the function %s located in the file %s': 'Qui a appelé la fonction %s se trouvant dans le fichier %s',
 'You are successfully running web2py': 'Vous roulez avec succès web2py',
 'You can modify this application and adapt it to your needs': "Vous pouvez modifier cette application et l'adapter à vos besoins",
-'You visited the url': "Vous avez visité l'URL",
-'about': 'à propos',
-'appadmin is disabled because insecure channel': "appadmin est désactivée parce que le canal n'est pas sécurisé",
-'cache': 'cache',
-'change password': 'changer le mot de passe',
-'customize me!': 'personnalisez-moi!',
-'data uploaded': 'données téléchargées',
-'database': 'base de données',
-'database %s select': 'base de données %s select',
-'db': 'db',
-'design': 'design',
-'done!': 'fait!',
-'edit profile': 'modifier le profil',
-'enter an integer between %(min)g and %(max)g': 'entrer un entier compris entre %(min)g et %(max)g',
-'export as csv file': 'exporter sous forme de fichier csv',
-'insert new': 'insérer un nouveau',
-'insert new %s': 'insérer un nouveau %s',
-'invalid request': 'requête invalide',
-'located in the file': 'se trouvant dans le fichier',
-'login': 'connectez-vous',
-'logout': 'déconnectez-vous',
-'lost password': 'mot de passe perdu',
-'lost password?': 'mot de passe perdu?',
-'new record inserted': 'nouvel enregistrement inséré',
-'next 100 rows': '100 prochaines lignes',
-'or import from csv file': "ou importer d'un fichier CSV",
-'password': 'mot de passe',
-'please input your password again': "S'il vous plaît entrer votre mot de passe",
-'previous 100 rows': '100 lignes précédentes',
-'profile': 'profile',
-'record': 'enregistrement',
-'record does not exist': "l'archive n'existe pas",
-'record id': "id d'enregistrement",
-'register': "s'inscrire",
-'selected': 'sélectionné',
-'state': 'état',
-'table': 'tableau',
-'unable to parse csv file': "incapable d'analyser le fichier cvs",
-'value already in database or empty': 'valeur déjà dans la base ou vide',
+'You visited the url %s': "Vous avez visité l'URL %s",
 }
-
