@@ -1,123 +1,227 @@
 # coding: utf8
 {
+'!langcode!': 'zh-cn',
+'!langname!': '中文',
 '"update" is an optional expression like "field1=\'newvalue\'". You cannot update or delete the results of a JOIN': '"更新" 是選擇性的條件式, 格式就像 "欄位1=\'值\'". 但是 JOIN 的資料不可以使用 update 或是 delete"',
+'%s %%{row} deleted': '已刪除 %s 筆',
+'%s %%{row} updated': '已更新 %s 筆',
+'%s selected': '%s 已選擇',
 '%Y-%m-%d': '%Y-%m-%d',
 '%Y-%m-%d %H:%M:%S': '%Y-%m-%d %H:%M:%S',
-'%s rows deleted': '已刪除 %s 筆',
-'%s rows updated': '已更新 %s 筆',
 '(something like "it-it")': '(格式類似 "zh-tw")',
 'A new version of web2py is available': '新版的 web2py 已發行',
 'A new version of web2py is available: %s': '新版的 web2py 已發行: %s',
+'about': '關於',
+'About': '關於',
+'About application': '關於本應用程式',
+'Access Control': 'Access Control',
+'Admin is disabled because insecure channel': '管理功能(Admin)在不安全連線環境下自動關閉',
+'Admin is disabled because unsecure channel': '管理功能(Admin)在不安全連線環境下自動關閉',
+'Administrative Interface': 'Administrative Interface',
+'Administrative interface': '點此處進入管理介面',
+'Administrator Password:': '管理員密碼:',
+'Ajax Recipes': 'Ajax Recipes',
+'An error occured, please %s the page': 'An error occured, please %s the page',
+'appadmin is disabled because insecure channel': '因為來自非安全通道,管理介面關閉',
+'Are you sure you want to delete file "%s"?': '確定要刪除檔案"%s"?',
+'Are you sure you want to delete this object?': 'Are you sure you want to delete this object?',
+'Are you sure you want to uninstall application "%s"': '確定要移除應用程式 "%s"',
+'Are you sure you want to uninstall application "%s"?': '確定要移除應用程式 "%s"',
 'ATTENTION: Login requires a secure (HTTPS) connection or running on localhost.': '注意: 登入管理帳號需要安全連線(HTTPS)或是在本機連線(localhost).',
 'ATTENTION: TESTING IS NOT THREAD SAFE SO DO NOT PERFORM MULTIPLE TESTS CONCURRENTLY.': '注意: 因為在測試模式不保證多執行緒安全性，也就是說不可以同時執行多個測試案例',
 'ATTENTION: you cannot edit the running application!': '注意:不可編輯正在執行的應用程式!',
-'About': '關於',
-'About application': '關於本應用程式',
-'Admin is disabled because insecure channel': '管理功能(Admin)在不安全連線環境下自動關閉',
-'Admin is disabled because unsecure channel': '管理功能(Admin)在不安全連線環境下自動關閉',
-'Administrator Password:': '管理員密碼:',
-'Are you sure you want to delete file "%s"?': '確定要刪除檔案"%s"?',
-'Are you sure you want to uninstall application "%s"': '確定要移除應用程式 "%s"',
-'Are you sure you want to uninstall application "%s"?': '確定要移除應用程式 "%s"',
 'Authentication': '驗證',
-'Available databases and tables': '可提供的資料庫和資料表',
+'Available Databases and Tables': '可提供的資料庫和資料表',
+'Buy this book': 'Buy this book',
+'cache': '快取記憶體',
+'Cache': 'Cache',
+'Cache Keys': 'Cache Keys',
 'Cannot be empty': '不可空白',
 'Cannot compile: there are errors in your app.        Debug it, correct errors and try again.': '無法編譯:應用程式中含有錯誤，請除錯後再試一次.',
 'Change Password': '變更密碼',
+'change password': '變更密碼',
 'Check to delete': '打勾代表刪除',
 'Check to delete:': '點選以示刪除:',
+'Clear CACHE?': 'Clear CACHE?',
+'Clear DISK': 'Clear DISK',
+'Clear RAM': 'Clear RAM',
 'Client IP': '客戶端網址(IP)',
+'Community': 'Community',
+'Components and Plugins': 'Components and Plugins',
 'Controller': '控件',
 'Controllers': '控件',
 'Copyright': '版權所有',
 'Create new application': '創建應用程式',
+'Created By': 'Created By',
+'Created On': 'Created On',
 'Current request': '目前網路資料要求(request)',
 'Current response': '目前網路資料回應(response)',
 'Current session': '目前網路連線資訊(session)',
-'DB Model': '資料庫模組',
-'DESIGN': '設計',
+'customize me!': '請調整我!',
+'data uploaded': '資料已上傳',
 'Database': '資料庫',
+'Database %s select': '已選擇 %s 資料庫',
 'Date and Time': '日期和時間',
+'db': 'db',
+'DB Model': '資料庫模組',
 'Delete': '刪除',
 'Delete:': '刪除:',
+'Demo': 'Demo',
 'Deploy on Google App Engine': '配置到 Google App Engine',
+'Deployment Recipes': 'Deployment Recipes',
 'Description': '描述',
+'DESIGN': '設計',
+'design': '設計',
 'Design for': '設計為了',
+'DISK': 'DISK',
+'Disk Cache Keys': 'Disk Cache Keys',
+'Disk Cleared': 'Disk Cleared',
+'Documentation': 'Documentation',
+"Don't know what to do?": "Don't know what to do?",
+'done!': '完成!',
+'Download': 'Download',
 'E-mail': '電子郵件',
 'EDIT': '編輯',
 'Edit': '編輯',
-'Edit Profile': '編輯設定檔',
-'Edit This App': '編輯本應用程式',
 'Edit application': '編輯應用程式',
 'Edit current record': '編輯當前紀錄',
+'edit profile': '編輯設定檔',
+'Edit Profile': '編輯設定檔',
+'Edit This App': '編輯本應用程式',
 'Editing file': '編輯檔案',
 'Editing file "%s"': '編輯檔案"%s"',
+'Email and SMS': 'Email and SMS',
+'enter an integer between %(min)g and %(max)g': 'enter an integer between %(min)g and %(max)g',
 'Error logs for "%(app)s"': '"%(app)s"的錯誤紀錄',
+'Errors': 'Errors',
+'export as csv file': '以逗號分隔檔(csv)格式匯出',
+'FAQ': 'FAQ',
 'First name': '名',
+'Forgot username?': 'Forgot username?',
+'Forms and Validators': 'Forms and Validators',
+'Free Applications': 'Free Applications',
 'Functions with no doctests will result in [passed] tests.': '沒有 doctests 的函式會顯示 [passed].',
 'Group ID': '群組編號',
+'Groups': 'Groups',
 'Hello World': '嗨! 世界',
+'Home': 'Home',
+'How did you get here?': 'How did you get here?',
+'import': 'import',
 'Import/Export': '匯入/匯出',
 'Index': '索引',
+'insert new': '插入新資料',
+'insert new %s': '插入新資料 %s',
 'Installed applications': '已安裝應用程式',
 'Internal State': '內部狀態',
-'Invalid Query': '不合法的查詢',
+'Introduction': 'Introduction',
 'Invalid action': '不合法的動作(action)',
 'Invalid email': '不合法的電子郵件',
+'Invalid Query': '不合法的查詢',
+'invalid request': '不合法的網路要求(request)',
+'Is Active': 'Is Active',
+'Key': 'Key',
 'Language files (static strings) updated': '語言檔已更新',
 'Languages': '各國語言',
 'Last name': '姓',
 'Last saved on:': '最後儲存時間:',
 'Layout': '網頁配置',
+'Layout Plugins': 'Layout Plugins',
+'Layouts': 'Layouts',
 'License for': '軟體版權為',
+'Live Chat': 'Live Chat',
+'login': '登入',
 'Login': '登入',
 'Login to the Administrative Interface': '登入到管理員介面',
+'logout': '登出',
 'Logout': '登出',
 'Lost Password': '密碼遺忘',
+'Lost password?': 'Lost password?',
 'Main Menu': '主選單',
+'Manage Cache': 'Manage Cache',
 'Menu Model': '選單模組(menu)',
 'Models': '資料模組',
+'Modified By': 'Modified By',
+'Modified On': 'Modified On',
 'Modules': '程式模組',
-'NO': '否',
+'My Sites': 'My Sites',
 'Name': '名字',
 'New Record': '新紀錄',
+'new record inserted': '已插入新紀錄',
+'next 100 rows': '往後 100 筆',
+'NO': '否',
 'No databases in this application': '這應用程式不含資料庫',
+'Object or table name': 'Object or table name',
+'Online examples': '點此處進入線上範例',
+'or import from csv file': '或是從逗號分隔檔(CSV)匯入',
 'Origin': '原文',
 'Original/Translation': '原文/翻譯',
+'Other Plugins': 'Other Plugins',
+'Other Recipes': 'Other Recipes',
+'Overview': 'Overview',
 'Password': '密碼',
 "Password fields don't match": '密碼欄不匹配',
 'Peeking at file': '選擇檔案',
+'Plugins': 'Plugins',
 'Powered by': '基於以下技術構建：',
+'Preface': 'Preface',
+'previous 100 rows': '往前 100 筆',
+'Python': 'Python',
 'Query:': '查詢:',
+'Quick Examples': 'Quick Examples',
+'RAM': 'RAM',
+'RAM Cache Keys': 'RAM Cache Keys',
+'Ram Cleared': 'Ram Cleared',
+'Recipes': 'Recipes',
+'Record': '紀錄',
+'record does not exist': '紀錄不存在',
 'Record ID': '紀錄編號',
+'Record id': '紀錄編號',
 'Register': '註冊',
+'register': '註冊',
+'Registration identifier': 'Registration identifier',
 'Registration key': '註冊金鑰',
+'reload': 'reload',
 'Remember me (for 30 days)': '記住我(30 天)',
 'Reset Password key': '重設密碼',
 'Resolve Conflict file': '解決衝突檔案',
 'Role': '角色',
-'Rows in table': '在資料表裏的資料',
+'Rows in Table': '在資料表裏的資料',
 'Rows selected': '筆資料被選擇',
 'Saved file hash:': '檔案雜湊值已紀錄:',
+'Semantic': 'Semantic',
+'Services': 'Services',
+'Size of cache:': 'Size of cache:',
+'state': '狀態',
 'Static files': '靜態檔案',
+'Statistics': 'Statistics',
 'Stylesheet': '網頁風格檔',
+'submit': 'submit',
 'Submit': '傳送',
+'Support': 'Support',
 'Sure you want to delete this object?': '確定要刪除此物件?',
+'Table': '資料表',
 'Table name': '資料表名稱',
 'Testing application': '測試中的應用程式',
 'The "query" is a condition like "db.table1.field1==\'value\'". Something like "db.table1.field1==db.table2.field2" results in a SQL JOIN.': '"查詢"是一個像 "db.表1.欄位1==\'值\'" 的條件式. 以"db.表1.欄位1==db.表2.欄位2"方式則相當於執行 JOIN SQL.',
+'The Core': 'The Core',
+'The output of the file is a dictionary that was rendered by the view %s': 'The output of the file is a dictionary that was rendered by the view %s',
+'The Views': 'The Views',
 'There are no controllers': '沒有控件(controllers)',
 'There are no models': '沒有資料庫模組(models)',
 'There are no modules': '沒有程式模組(modules)',
 'There are no static files': '沒有靜態檔案',
 'There are no translators, only default language is supported': '沒有翻譯檔,只支援原始語言',
 'There are no views': '沒有視圖',
+'This App': 'This App',
 'This is the %(filename)s template': '這是%(filename)s檔案的樣板(template)',
 'Ticket': '問題單',
+'Time in Cache (h:m:s)': 'Time in Cache (h:m:s)',
 'Timestamp': '時間標記',
+'Twitter': 'Twitter',
 'Unable to check for upgrades': '無法做升級檢查',
 'Unable to download': '無法下載',
 'Unable to download app': '無法下載應用程式',
+'unable to parse csv file': '無法解析逗號分隔檔(csv)',
 'Update:': '更新:',
 'Upload existing application': '更新存在的應用程式',
 'Use (...)&(...) for AND, (...)|(...) for OR, and ~(...)  for NOT to build more complex queries.': '使用下列方式來組合更複雜的條件式, (...)&(...) 代表同時存在的條件, (...)|(...) 代表擇一的條件, ~(...)則代表反向條件.',
@@ -125,42 +229,16 @@
 'User %(id)s Registered': '使用者 %(id)s 已註冊',
 'User ID': '使用者編號',
 'Verify Password': '驗證密碼',
+'Videos': 'Videos',
 'View': '視圖',
 'Views': '視圖',
+'Welcome': 'Welcome',
 'Welcome %s': '歡迎 %s',
 'Welcome to web2py': '歡迎使用 web2py',
+'Welcome to web2py!': 'Welcome to web2py!',
+'Which called the function %s located in the file %s': 'Which called the function %s located in the file %s',
 'YES': '是',
-'about': '關於',
-'appadmin is disabled because insecure channel': '因為來自非安全通道,管理介面關閉',
-'cache': '快取記憶體',
-'change password': '變更密碼',
-'Online examples': '點此處進入線上範例',
-'Administrative interface': '點此處進入管理介面',
-'customize me!': '請調整我!',
-'data uploaded': '資料已上傳',
-'database': '資料庫',
-'database %s select': '已選擇 %s 資料庫',
-'db': 'db',
-'design': '設計',
-'done!': '完成!',
-'edit profile': '編輯設定檔',
-'export as csv file': '以逗號分隔檔(csv)格式匯出',
-'insert new': '插入新資料',
-'insert new %s': '插入新資料 %s',
-'invalid request': '不合法的網路要求(request)',
-'login': '登入',
-'logout': '登出',
-'new record inserted': '已插入新紀錄',
-'next 100 rows': '往後 100 筆',
-'or import from csv file': '或是從逗號分隔檔(CSV)匯入',
-'previous 100 rows': '往前 100 筆',
-'record': '紀錄',
-'record does not exist': '紀錄不存在',
-'record id': '紀錄編號',
-'register': '註冊',
-'selected': '已選擇',
-'state': '狀態',
-'table': '資料表',
-'unable to parse csv file': '無法解析逗號分隔檔(csv)',
+'You are successfully running web2py': 'You are successfully running web2py',
+'You can modify this application and adapt it to your needs': 'You can modify this application and adapt it to your needs',
+'You visited the url %s': 'You visited the url %s',
 }
-
