@@ -2,20 +2,20 @@
 # -*- coding: utf-8 -*-
 
 """
-This file is part of the web2py Web Framework
-Copyrighted by Massimo Di Pierro <mdipierro@cs.depaul.edu>
-License: LGPLv3 (http://www.gnu.org/licenses/lgpl.html)
+| This file is part of the web2py Web Framework
+| Copyrighted by Massimo Di Pierro <mdipierro@cs.depaul.edu>
+| License: LGPLv3 (http://www.gnu.org/licenses/lgpl.html)
 
 Functions required to execute app components
-============================================
+--------------------------------------------
 
-FOR INTERNAL USE ONLY
+Note:
+    FOR INTERNAL USE ONLY
 """
 
 from os import stat
 import thread
-import logging
-from fileutils import read_file
+from gluon.fileutils import read_file
 
 cfs = {}  # for speed-up
 cfs_lock = thread.allocate_lock()  # and thread safety
@@ -26,11 +26,12 @@ def getcfs(key, filename, filter=None):
     Caches the *filtered* file `filename` with `key` until the file is
     modified.
 
-    :param key: the cache key
-    :param filename: the file to cache
-    :param filter: is the function used for filtering. Normally `filename` is a
-        .py file and `filter` is a function that bytecode compiles the file.
-        In this way the bytecode compiled file is cached. (Default = None)
+    Args:
+        key(str): the cache key
+        filename: the file to cache
+        filter: is the function used for filtering. Normally `filename` is a
+            .py file and `filter` is a function that bytecode compiles the file.
+            In this way the bytecode compiled file is cached. (Default = None)
 
     This is used on Google App Engine since pyc files cannot be saved.
     """
@@ -51,10 +52,3 @@ def getcfs(key, filename, filter=None):
     cfs[key] = (t, data)
     cfs_lock.release()
     return data
-
-
-
-
-
-
-
