@@ -4,13 +4,14 @@
 """
 This file is part of web2py Web Framework (Copyrighted, 2007-2009).
 Developed by Massimo Di Pierro <mdipierro@cs.depaul.edu>.
-License: GPL v2
+License: LGPL v3
 
 Thanks to Hans Donner <hans.donner@pobox.com> for GaeGoogleAccount.
 """
 
 from google.appengine.api import users
 
+
 class GaeGoogleAccount(object):
     """
     Login will be done via Google's Appengine login object, instead of web2py's
@@ -33,7 +34,8 @@ class GaeGoogleAccount(object):
     def get_user(self):
         user = users.get_current_user()
         if user:
-            return dict(nickname=user.nickname(), email=user.email(),
-                        user_id=user.user_id(), source="google account")
-
-
+            return dict(nickname = user.nickname(),
+                        email = user.email(),
+                        registration_id = user.user_id(),
+                        user_id = user.user_id(),
+                        source = "google account")
