@@ -16,7 +16,9 @@ except Exception, e:
 
 def ldap_auth(server='ldap', port=None,
               base_dn='ou=users,dc=domain,dc=com',
-              mode='uid', secure=False, cert_path=None, cert_file=None,
+              mode='uid', secure=False, 
+              cert_path=None, cert_file=None,              
+              cacert_path=None, cacert_file=None, key_file=None,
               bind_dn=None, bind_pw=None, filterstr='objectClass=*',
               username_attrib='uid',
               custom_scope='subtree',
@@ -31,6 +33,7 @@ def ldap_auth(server='ldap', port=None,
               group_name_attrib='cn',
               group_member_attrib='memberUid',
               group_filterstr='objectClass=*',
+              tls=False,
               logging_level='error'):
 
     """
@@ -78,6 +81,13 @@ def ldap_auth(server='ldap', port=None,
     If ldap is using GnuTLS then you need cert_file="..." instead cert_path
     because cert_path isn't implemented in GnuTLS :(
 
+    To enable TLS, set tls=True:
+
+        auth.settings.login_methods.append(ldap_auth(
+            server='my.ldap.server',
+            base_dn='ou=Users,dc=domain,dc=com',
+            tls=True))
+
     If you need to bind to the directory with an admin account in order to
     search it then specify bind_dn & bind_pw to use for this.
     - currently only implemented for Active Directory
@@ -170,6 +180,8 @@ def ldap_auth(server='ldap', port=None,
                       secure=secure,
                       cert_path=cert_path,
                       cert_file=cert_file,
+                      cacert_file=cacert_file,
+                      key_file=key_file,
                       filterstr=filterstr,
                       username_attrib=username_attrib,
                       custom_scope=custom_scope,
@@ -188,18 +200,23 @@ def ldap_auth(server='ldap', port=None,
                      str(custom_scope), str(manage_groups)))
         if manage_user:
             if user_firstname_attrib.count(':') > 0:
-                (user_firstname_attrib, user_firstname_part) = user_firstname_attrib.split(':', 1)
+                (user_firstname_attrib,
+                 user_firstname_part) = user_firstname_attrib.split(':', 1)
                 user_firstname_part = (int(user_firstname_part) - 1)
             else:
                 user_firstname_part = None
             if user_lastname_attrib.count(':') > 0:
-                (user_lastname_attrib, user_lastname_part) = user_lastname_attrib.split(':', 1)
+                (user_lastname_attrib,
+                 user_lastname_part) = user_lastname_attrib.split(':', 1)
                 user_lastname_part = (int(user_lastname_part) - 1)
             else:
                 user_lastname_part = None
-            user_firstname_attrib = ldap.filter.escape_filter_chars(user_firstname_attrib)
-            user_lastname_attrib = ldap.filter.escape_filter_chars(user_lastname_attrib)
-            user_mail_attrib = ldap.filter.escape_filter_chars(user_mail_attrib)
+            user_firstname_attrib = ldap.filter.escape_filter_chars(
+                user_firstname_attrib)
+            user_lastname_attrib = ldap.filter.escape_filter_chars(
+                user_lastname_attrib)
+            user_mail_attrib = ldap.filter.escape_filter_chars(
+                user_mail_attrib)
         try:
             if allowed_groups:
                 if not is_user_in_allowed_groups(username, password):
@@ -217,7 +234,8 @@ def ldap_auth(server='ldap', port=None,
                 con.set_option(ldap.OPT_PROTOCOL_VERSION, 3)
                 # In cases where ForestDnsZones and DomainDnsZones are found,
                 # result will look like the following:
-                # ['ldap://ForestDnsZones.domain.com/DC=ForestDnsZones,DC=domain,DC=com']
+                # ['ldap://ForestDnsZones.domain.com/DC=ForestDnsZones,
+                #    DC=domain,DC=com']
                 if ldap_binddn:
                     # need to search directory with an admin account 1st
                     con.simple_bind_s(ldap_binddn, ldap_bindpw)
@@ -233,8 +251,9 @@ def ldap_auth(server='ldap', port=None,
                                            user_mail_attrib])
                 result = con.search_ext_s(
                     ldap_basedn, ldap.SCOPE_SUBTREE,
-                    "(&(sAMAccountName=%s)(%s))" % (ldap.filter.escape_filter_chars(username_bare),
-                                                    filterstr),
+                    "(&(sAMAccountName=%s)(%s))" % (
+                                ldap.filter.escape_filter_chars(username_bare),
+                                filterstr),
                     requested_attrs)[0][1]
                 if not isinstance(result, dict):
                     # result should be a dict in the form
@@ -260,6 +279,8 @@ def ldap_auth(server='ldap', port=None,
 
             if ldap_mode == 'cn':
                 # OpenLDAP (CN)
+                if ldap_binddn and ldap_bindpw:
+                    con.simple_bind_s(ldap_binddn, ldap_bindpw)
                 dn = "cn=" + username + "," + ldap_basedn
                 con.simple_bind_s(dn, password)
                 if manage_user:
@@ -271,7 +292,12 @@ def ldap_auth(server='ldap', port=None,
 
             if ldap_mode == 'uid':
                 # OpenLDAP (UID)
-                dn = "uid=" + username + "," + ldap_basedn
+                if ldap_binddn and ldap_bindpw:
+                    con.simple_bind_s(ldap_binddn, ldap_bindpw)
+                    dn = "uid=" + username + "," + ldap_basedn
+                    dn = con.search_s(ldap_basedn, ldap.SCOPE_SUBTREE, "(uid=%s)"%username, [''])[0][0]
+                else:
+                    dn = "uid=" + username + "," + ldap_basedn
                 con.simple_bind_s(dn, password)
                 if manage_user:
                     result = con.search_s(dn, ldap.SCOPE_BASE,
@@ -287,8 +313,9 @@ def ldap_auth(server='ldap', port=None,
                 # bind anonymously
                 con.simple_bind_s(dn, pw)
                 # search by e-mail address
-                filter = '(&(mail=%s)(%s))' % (ldap.filter.escape_filter_chars(username),
-                                               filterstr)
+                filter = '(&(mail=%s)(%s))' % (
+                                ldap.filter.escape_filter_chars(username),
+                                filterstr)
                 # find the uid
                 attrs = ['uid']
                 if manage_user:
@@ -310,7 +337,8 @@ def ldap_auth(server='ldap', port=None,
                     basedns = ldap_basedn
                 else:
                     basedns = [ldap_basedn]
-                filter = '(&(uid=%s)(%s))' % (ldap.filter.escape_filter_chars(username), filterstr)
+                filter = '(&(uid=%s)(%s))' % (
+                    ldap.filter.escape_filter_chars(username), filterstr)
                 found = False
                 for basedn in basedns:
                     try:
@@ -324,8 +352,10 @@ def ldap_auth(server='ldap', port=None,
                             break
                     except ldap.LDAPError, detail:
                         (exc_type, exc_value) = sys.exc_info()[:2]
-                        logger.warning("ldap_auth: searching %s for %s resulted in %s: %s\n" %
-                                       (basedn, filter, exc_type, exc_value))
+                        logger.warning(
+                        "ldap_auth: searching %s for %s resulted in %s: %s\n" %
+                                       (basedn, filter, exc_type, exc_value)
+                                       )
                 if not found:
                     logger.warning('User [%s] not found!' % username)
                     return False
@@ -338,7 +368,8 @@ def ldap_auth(server='ldap', port=None,
                 else:
                     basedns = [ldap_basedn]
                 filter = '(&(%s=%s)(%s))' % (username_attrib,
-                                             ldap.filter.escape_filter_chars(username),
+                                             ldap.filter.escape_filter_chars(
+                                                 username),
                                              filterstr)
                 if custom_scope == 'subtree':
                     ldap_scope = ldap.SCOPE_SUBTREE
@@ -358,8 +389,10 @@ def ldap_auth(server='ldap', port=None,
                             break
                     except ldap.LDAPError, detail:
                         (exc_type, exc_value) = sys.exc_info()[:2]
-                        logger.warning("ldap_auth: searching %s for %s resulted in %s: %s\n" %
-                                       (basedn, filter, exc_type, exc_value))
+                        logger.warning(
+                        "ldap_auth: searching %s for %s resulted in %s: %s\n" %
+                                       (basedn, filter, exc_type, exc_value)
+                                       )
                 if not found:
                     logger.warning('User [%s] not found!' % username)
                     return False
@@ -368,14 +401,16 @@ def ldap_auth(server='ldap', port=None,
                 logger.info('[%s] Manage user data' % str(username))
                 try:
                     if user_firstname_part is not None:
-                        store_user_firstname = result[user_firstname_attrib][0].split(' ', 1)[user_firstname_part]
+                        store_user_firstname = result[user_firstname_attrib][
+                            0].split(' ', 1)[user_firstname_part]
                     else:
                         store_user_firstname = result[user_firstname_attrib][0]
                 except KeyError, e:
                     store_user_firstname = None
                 try:
                     if user_lastname_part is not None:
-                        store_user_lastname = result[user_lastname_attrib][0].split(' ', 1)[user_lastname_part]
+                        store_user_lastname = result[user_lastname_attrib][
+                            0].split(' ', 1)[user_lastname_part]
                     else:
                         store_user_lastname = result[user_lastname_attrib][0]
                 except KeyError, e:
@@ -416,6 +451,8 @@ def ldap_auth(server='ldap', port=None,
                 if not do_manage_groups(username, password):
                     return False
             return True
+        except ldap.INVALID_CREDENTIALS, e:
+            return False
         except ldap.LDAPError, e:
             import traceback
             logger.warning('[%s] Error in ldap processing' % str(username))
@@ -464,16 +501,19 @@ def ldap_auth(server='ldap', port=None,
             #
             # Get all group name where the user is in actually in ldap
             # #########################################################
-            ldap_groups_of_the_user = get_user_groups_from_ldap(username, password)
+            ldap_groups_of_the_user = get_user_groups_from_ldap(
+                username, password)
 
             #
             # Get all group name where the user is in actually in local db
             # #############################################################
             try:
-                db_user_id = db(db.auth_user.username == username).select(db.auth_user.id).first().id
+                db_user_id = db(db.auth_user.username == username).select(
+                    db.auth_user.id).first().id
             except:
                 try:
-                    db_user_id = db(db.auth_user.email == username).select(db.auth_user.id).first().id
+                    db_user_id = db(db.auth_user.email == username).select(
+                        db.auth_user.id).first().id
                 except AttributeError, e:
                     #
                     # There is no user in local db
@@ -486,11 +526,22 @@ def ldap_auth(server='ldap', port=None,
                         db_user_id = db.auth_user.insert(email=username,
                                                          first_name=username)
             if not db_user_id:
-                logging.error('There is no username or email for %s!' % username)
+                logging.error(
+                    'There is no username or email for %s!' % username)
                 raise
-            db_group_search = db((db.auth_membership.user_id == db_user_id) &
-                                (db.auth_user.id == db.auth_membership.user_id) &
-                                 (db.auth_group.id == db.auth_membership.group_id))
+            # if old pydal version, assume this is a relational database which can do joins
+            db_can_join = db.can_join() if hasattr(db, 'can_join') else True
+            if db_can_join:
+                db_group_search = db(
+                    (db.auth_membership.user_id == db_user_id) &
+                    (db.auth_user.id == db.auth_membership.user_id) &
+                    (db.auth_group.id == db.auth_membership.group_id))
+            else:
+                # no joins on NoSQL databases, perform two queries
+                db_group_search = db(db.auth_membership.user_id == db_user_id)
+                group_ids = [x.group_id for x in db_group_search.select(
+                        db.auth_membership.group_id, distinct=True)]
+                db_group_search = db(db.auth_group.id.belongs(group_ids))
             db_groups_of_the_user = list()
             db_group_id = dict()
 
@@ -509,7 +560,8 @@ def ldap_auth(server='ldap', port=None,
             for group_to_del in db_groups_of_the_user:
                 if ldap_groups_of_the_user.count(group_to_del) == 0:
                     db((db.auth_membership.user_id == db_user_id) &
-                       (db.auth_membership.group_id == db_group_id[group_to_del])).delete()
+                       (db.auth_membership.group_id == \
+                         db_group_id[group_to_del])).delete()
 
             #
             # Create user membership in groups where user is not in already
@@ -518,9 +570,10 @@ def ldap_auth(server='ldap', port=None,
                 if db_groups_of_the_user.count(group_to_add) == 0:
                     if db(db.auth_group.role == group_to_add).count() == 0:
                         gid = db.auth_group.insert(role=group_to_add,
-                                                   description='Generated from LDAP')
+                                            description='Generated from LDAP')
                     else:
-                        gid = db(db.auth_group.role == group_to_add).select(db.auth_group.id).first().id
+                        gid = db(db.auth_group.role == group_to_add).select(
+                            db.auth_group.id).first().id
                     db.auth_membership.insert(user_id=db_user_id,
                                               group_id=gid)
         except:
@@ -537,7 +590,9 @@ def ldap_auth(server='ldap', port=None,
                   ldap_mode=mode,
                   secure=secure,
                   cert_path=cert_path,
-                  cert_file=cert_file):
+                  cert_file=cert_file,
+                  cacert_file=cacert_file,
+                  key_file=key_file):
         """
         Inicialize ldap connection
         """
@@ -545,17 +600,26 @@ def ldap_auth(server='ldap', port=None,
         if secure:
             if not ldap_port:
                 ldap_port = 636
-            con = ldap.initialize(
-                "ldaps://" + ldap_server + ":" + str(ldap_port))
-            if cert_path:
-                con.set_option(ldap.OPT_X_TLS_CACERTDIR, cert_path)
+                
+            if cacert_path:
+                ldap.set_option(ldap.OPT_X_TLS_CACERTDIR, cacert_path)
+                
+            if cacert_file:
+                ldap.set_option(ldap.OPT_X_TLS_REQUIRE_CERT, ldap.OPT_X_TLS_NEVER)
+                ldap.set_option(ldap.OPT_X_TLS_CACERTFILE, cacert_file)
             if cert_file:
-                con.set_option(ldap.OPT_X_TLS_CACERTFILE, cert_file)
+                ldap.set_option(ldap.OPT_X_TLS_CERTFILE, cert_file)
+            if key_file:
+                ldap.set_option(ldap.OPT_X_TLS_KEYFILE, key_file)
+                
+            con = ldap.initialize("ldaps://" + ldap_server + ":" + str(ldap_port))
         else:
             if not ldap_port:
                 ldap_port = 389
             con = ldap.initialize(
                 "ldap://" + ldap_server + ":" + str(ldap_port))
+        if tls:
+            con.start_tls_s()
         return con
 
     def get_user_groups_from_ldap(username,
@@ -594,7 +658,8 @@ def ldap_auth(server='ldap', port=None,
             con.set_option(ldap.OPT_PROTOCOL_VERSION, 3)
             # In cases where ForestDnsZones and DomainDnsZones are found,
             # result will look like the following:
-            # ['ldap://ForestDnsZones.domain.com/DC=ForestDnsZones,DC=domain,DC=com']
+            # ['ldap://ForestDnsZones.domain.com/DC=ForestDnsZones,
+            #     DC=domain,DC=com']
             if ldap_binddn:
                 # need to search directory with an admin account 1st
                 con.simple_bind_s(ldap_binddn, ldap_bindpw)
@@ -606,7 +671,8 @@ def ldap_auth(server='ldap', port=None,
             # We have to use the full string
             username = con.search_ext_s(base_dn, ldap.SCOPE_SUBTREE,
                                         "(&(sAMAccountName=%s)(%s))" %
-                                        (ldap.filter.escape_filter_chars(username_bare), filterstr), ["cn"])[0][0]
+                            (ldap.filter.escape_filter_chars(username_bare),
+                            filterstr), ["cn"])[0][0]
         else:
             if ldap_binddn:
                 # need to search directory with an bind_dn account 1st
@@ -614,9 +680,14 @@ def ldap_auth(server='ldap', port=None,
             else:
                 # bind as anonymous
                 con.simple_bind_s('', '')
-
+                
+        # if username is None, return empty list
+        if username is None:
+            return list()
         # search for groups where user is in
-        filter = '(&(%s=%s)(%s))' % (ldap.filter.escape_filter_chars(group_member_attrib),
+        filter = '(&(%s=%s)(%s))' % (ldap.filter.escape_filter_chars(
+                                                            group_member_attrib
+                                                            ),
                                      ldap.filter.escape_filter_chars(username),
                                      group_filterstr)
         group_search_result = con.search_s(group_dn,
@@ -625,7 +696,8 @@ def ldap_auth(server='ldap', port=None,
         ldap_groups_of_the_user = list()
         for group_row in group_search_result:
             group = group_row[1]
-            ldap_groups_of_the_user.extend(group[group_name_attrib])
+            if type(group) == dict and group.has_key(group_name_attrib):
+                ldap_groups_of_the_user.extend(group[group_name_attrib])
 
         con.unbind()
         logger.debug('User groups: %s' % ldap_groups_of_the_user)
@@ -634,4 +706,3 @@ def ldap_auth(server='ldap', port=None,
     if filterstr[0] == '(' and filterstr[-1] == ')':  # rfc4515 syntax
         filterstr = filterstr[1:-1]  # parens added again where used
     return ldap_auth_aux
-
