@@ -23,13 +23,13 @@ THE SOFTWARE.
 
 '''
 
-VERSION = (0, 4, None)
+VERSION = (0, 5, None)
 
 from constants import FIELD_TYPE
 from converters import escape_dict, escape_sequence, escape_string
 from err import Warning, Error, InterfaceError, DataError, \
      DatabaseError, OperationalError, IntegrityError, InternalError, \
-     NotSupportedError, ProgrammingError
+     NotSupportedError, ProgrammingError, MySQLError
 from times import Date, Time, Timestamp, \
     DateFromTicks, TimeFromTicks, TimestampFromTicks
 
@@ -110,7 +110,7 @@ def thread_safe():
 def install_as_MySQLdb():
     """
     After this function is called, any application that imports MySQLdb or
-    _mysql will unwittingly actually use
+    _mysql will unwittingly actually use 
     """
     sys.modules["MySQLdb"] = sys.modules["_mysql"] = sys.modules["pymysql"]
 
@@ -121,12 +121,11 @@ __all__ = [
     'InterfaceError', 'InternalError', 'MySQLError', 'NULL', 'NUMBER',
     'NotSupportedError', 'DBAPISet', 'OperationalError', 'ProgrammingError',
     'ROWID', 'STRING', 'TIME', 'TIMESTAMP', 'Warning', 'apilevel', 'connect',
-    'connections', 'constants', 'converters', 'cursors', 'debug', 'escape',
+    'connections', 'constants', 'converters', 'cursors',
     'escape_dict', 'escape_sequence', 'escape_string', 'get_client_info',
-    'paramstyle', 'string_literal', 'threadsafety', 'version_info',
+    'paramstyle', 'threadsafety', 'version_info',
 
     "install_as_MySQLdb",
 
     "NULL","__version__",
     ]
-
