@@ -2,9 +2,12 @@
 # -*- coding: utf-8 -*-
 
 """
-This file is part of the web2py Web Framework
-Copyrighted by Massimo Di Pierro <mdipierro@cs.depaul.edu>
-License: LGPLv3 (http://www.gnu.org/licenses/lgpl.html)
+| This file is part of the web2py Web Framework
+| Copyrighted by Massimo Di Pierro <mdipierro@cs.depaul.edu>
+| License: LGPLv3 (http://www.gnu.org/licenses/lgpl.html)
+
+File operations
+---------------
 """
 
 import storage
@@ -14,9 +17,10 @@ import tarfile
 import glob
 import time
 import datetime
+import logging
 from http import HTTP
 from gzip import open as gzopen
-
+from recfile import generate
 
 __all__ = [
     'parse_version',
@@ -40,55 +44,109 @@ __all__ = [
     'w2p_unpack_plugin',
     'fix_newlines',
     'make_fake_file_like_object',
-    ]
+]
 
-def parse_version(version = "Version 1.99.0 (2011-09-19 08:23:26)"):
+
+def parse_semantic(version="Version 1.99.0-rc.1+timestamp.2011.09.19.08.23.26"):
+    """Parses a version string according to http://semver.org/ rules
+
+    Args:
+        version(str): the SemVer string
+
+    Returns:
+        tuple: Major, Minor, Patch, Release, Build Date
+
+    """
+    re_version = re.compile('(\d+)\.(\d+)\.(\d+)(\-(?P<pre>[^\s+]*))?(\+(?P<build>\S*))')
+    m = re_version.match(version.strip().split()[-1])
+    if not m:
+        return None
+    a, b, c = int(m.group(1)), int(m.group(2)), int(m.group(3))
+    pre_release = m.group('pre') or ''
+    build = m.group('build') or ''
+    if build.startswith('timestamp'):
+        build = datetime.datetime.strptime(build.split('.', 1)[1], '%Y.%m.%d.%H.%M.%S')
+    return (a, b, c, pre_release, build)
+
+
+def parse_legacy(version="Version 1.99.0 (2011-09-19 08:23:26)"):
+    """Parses "legacy" version string
+
+    Args:
+        version(str): the version string
+
+    Returns:
+        tuple: Major, Minor, Patch, Release, Build Date
+
+    """
     re_version = re.compile('[^\d]+ (\d+)\.(\d+)\.(\d+)\s*\((?P<datetime>.+?)\)\s*(?P<type>[a-z]+)?')
     m = re_version.match(version)
-    a,b,c = int(m.group(1)),int(m.group(2)),int(m.group(3)),
-    s = m.group('type') or 'dev'
-    d = datetime.datetime.strptime(m.group('datetime'),'%Y-%m-%d %H:%M:%S')
-    return (a,b,c,d,s)
+    a, b, c = int(m.group(1)), int(m.group(2)), int(m.group(3)),
+    pre_release = m.group('type') or 'dev'
+    build = datetime.datetime.strptime(m.group('datetime'), '%Y-%m-%d %H:%M:%S')
+    return (a, b, c, pre_release, build)
+
+
+def parse_version(version):
+    """Attempts to parse SemVer, fallbacks on legacy
+    """
+    version_tuple = parse_semantic(version)
+    if not version_tuple:
+        version_tuple = parse_legacy(version)
+    return version_tuple
+
 
 def read_file(filename, mode='r'):
-    "returns content from filename, making sure to close the file explicitly on exit."
+    """Returns content from filename, making sure to close the file explicitly
+    on exit.
+    """
     f = open(filename, mode)
     try:
         return f.read()
     finally:
         f.close()
 
+
 def write_file(filename, value, mode='w'):
-    "writes <value> to filename, making sure to close the file explicitly on exit."
+    """Writes <value> to filename, making sure to close the file
+    explicitly on exit.
+    """
     f = open(filename, mode)
     try:
         return f.write(value)
     finally:
         f.close()
 
+
 def readlines_file(filename, mode='r'):
-    "applies .split('\n') to the output of read_file()"
+    """Applies .split('\n') to the output of `read_file()`
+    """
     return read_file(filename, mode).split('\n')
 
 
 def mktree(path):
-    head,tail =os.path.split(path)
+    head, tail = os.path.split(path)
     if head:
-        if tail: mktree(head)
+        if tail:
+            mktree(head)
         if not os.path.exists(head):
             os.mkdir(head)
 
-def listdir(
-    path,
-    expression='^.+$',
-    drop=True,
-    add_dirs=False,
-    sort=True,
-    ):
+
+def listdir(path,
+            expression='^.+$',
+            drop=True,
+            add_dirs=False,
+            sort=True,
+            maxnum=None,
+            exclude_content_from=None
+            ):
     """
-    like os.listdir() but you can specify a regex pattern to filter files.
-    if add_dirs is True, the returned items will have the full path.
+    Like `os.listdir()` but you can specify a regex pattern to filter files.
+    If `add_dirs` is True, the returned items will have the full path.
     """
+    if exclude_content_from is None:
+        exclude_content_from = []
     if path[-1:] != os.path.sep:
         path = path + os.path.sep
     if drop:
@@ -105,7 +163,10 @@ def listdir(
             items.append(root[n:])
         for file in sorted(files):
             if regex.match(file) and not file.startswith('.'):
-                items.append(os.path.join(root, file)[n:])
+                if root not in exclude_content_from:
+                    items.append(os.path.join(root, file)[n:])
+            if maxnum and len(items) >= maxnum:
+                break
     if sort:
         return sorted(items)
     else:
@@ -113,118 +174,78 @@ def listdir(
 
 
 def recursive_unlink(f):
+    """Deletes `f`. If it's a folder, also its contents will be deleted
+    """
     if os.path.isdir(f):
         for s in os.listdir(f):
-            recursive_unlink(os.path.join(f,s))
+            recursive_unlink(os.path.join(f, s))
         os.rmdir(f)
     elif os.path.isfile(f):
         os.unlink(f)
 
 
 def cleanpath(path):
-    """
-    turns any expression/path into a valid filename. replaces / with _ and
+    """Turns any expression/path into a valid filename. replaces / with _ and
     removes special characters.
     """
 
     items = path.split('.')
     if len(items) > 1:
         path = re.sub('[^\w\.]+', '_', '_'.join(items[:-1]) + '.'
-                       + ''.join(items[-1:]))
+                      + ''.join(items[-1:]))
     else:
         path = re.sub('[^\w\.]+', '_', ''.join(items[-1:]))
     return path
 
 
 def _extractall(filename, path='.', members=None):
-    if not hasattr(tarfile.TarFile, 'extractall'):
-        from tarfile import ExtractError
-
-        class TarFile(tarfile.TarFile):
-
-            def extractall(self, path='.', members=None):
-                """Extract all members from the archive to the current working
-             directory and set owner, modification time and permissions on
-             directories afterwards. `path' specifies a different directory
-             to extract to. `members' is optional and must be a subset of the
-             list returned by getmembers().
-                """
-
-                directories = []
-                if members is None:
-                    members = self
-                for tarinfo in members:
-                    if tarinfo.isdir():
-
-                        # Extract directory with a safe mode, so that
-                        # all files below can be extracted as well.
-
-                        try:
-                            os.makedirs(os.path.join(path,
-                                    tarinfo.name), 0777)
-                        except EnvironmentError:
-                            pass
-                        directories.append(tarinfo)
-                    else:
-                        self.extract(tarinfo, path)
-
-                # Reverse sort directories.
-
-                directories.sort(lambda a, b: cmp(a.name, b.name))
-                directories.reverse()
-
-                # Set correct owner, mtime and filemode on directories.
-
-                for tarinfo in directories:
-                    path = os.path.join(path, tarinfo.name)
-                    try:
-                        self.chown(tarinfo, path)
-                        self.utime(tarinfo, path)
-                        self.chmod(tarinfo, path)
-                    except ExtractError, e:
-                        if self.errorlevel > 1:
-                            raise
-                        else:
-                            self._dbg(1, 'tarfile: %s' % e)
-
-
-        _cls = TarFile
-    else:
-        _cls = tarfile.TarFile
-
-    tar = _cls(filename, 'r')
+    tar = tarfile.TarFile(filename, 'r')
     ret = tar.extractall(path, members)
     tar.close()
     return ret
 
-def tar(file, dir, expression='^.+$'):
-    """
-    tars dir into file, only tars file that match expression
+
+def tar(file, dir, expression='^.+$',
+        filenames=None, exclude_content_from=None):
+    """Tars dir into file, only tars file that match expression
     """
 
     tar = tarfile.TarFile(file, 'w')
     try:
-        for file in listdir(dir, expression, add_dirs=True):
+        if filenames is None:
+            filenames = listdir(dir, expression, add_dirs=True,
+                exclude_content_from=exclude_content_from)
+        for file in filenames:
             tar.add(os.path.join(dir, file), file, False)
     finally:
         tar.close()
 
+
 def untar(file, dir):
-    """
-    untar file into dir
+    """Untar file into dir
     """
 
     _extractall(file, dir)
 
 
-def w2p_pack(filename, path, compiled=False):
+def w2p_pack(filename, path, compiled=False, filenames=None):
+    """Packs a web2py application.
+
+    Args:
+        filename(str): path to the resulting archive
+        path(str): path to the application
+        compiled(bool): if `True` packs the compiled version
+        filenames(list): adds filenames to the archive
+    """
     filename = abspath(filename)
     path = abspath(path)
     tarname = filename + '.tar'
     if compiled:
-        tar_compiled(tarname, path, '^[\w\.\-]+$')
+        tar_compiled(tarname, path, '^[\w\.\-]+$',
+                     exclude_content_from=['cache', 'sessions', 'errors'])
     else:
-        tar(tarname, path, '^[\w\.\-]+$')
+        tar(tarname, path, '^[\w\.\-]+$', filenames=filenames,
+            exclude_content_from=['cache', 'sessions', 'errors'])
     w2pfp = gzopen(filename, 'wb')
     tarfp = open(tarname, 'rb')
     w2pfp.write(tarfp.read())
@@ -232,7 +253,21 @@ def w2p_pack(filename, path, compiled=False):
     tarfp.close()
     os.unlink(tarname)
 
+
+def create_welcome_w2p():
+    if not os.path.exists('welcome.w2p') or os.path.exists('NEWINSTALL'):
+        try:
+            w2p_pack('welcome.w2p', 'applications/welcome')
+            os.unlink('NEWINSTALL')
+            logging.info("New installation: created welcome.w2p file")
+        except:
+            logging.error("New installation error: unable to create welcome.w2p file")
+
+
 def w2p_unpack(filename, path, delete_tar=True):
+
+    if filename == 'welcome.w2p':
+        create_welcome_w2p()
     filename = abspath(filename)
     path = abspath(path)
     if filename[-4:] == '.w2p' or filename[-3:] == '.gz':
@@ -253,24 +288,28 @@ def w2p_unpack(filename, path, delete_tar=True):
 
 
 def w2p_pack_plugin(filename, path, plugin_name):
-    """Pack the given plugin into a w2p file.
-    Will match files at:
+    """Packs the given plugin into a w2p file.
+    Will match files at::
+
         <path>/*/plugin_[name].*
         <path>/*/plugin_[name]/*
+
     """
     filename = abspath(filename)
     path = abspath(path)
     if not filename.endswith('web2py.plugin.%s.w2p' % plugin_name):
-        raise Exception, "Not a web2py plugin name"
+        raise Exception("Not a web2py plugin name")
     plugin_tarball = tarfile.open(filename, 'w:gz')
     try:
         app_dir = path
-        while app_dir[-1]=='/':
+        while app_dir[-1] == '/':
             app_dir = app_dir[:-1]
-        files1=glob.glob(os.path.join(app_dir,'*/plugin_%s.*' % plugin_name))
-        files2=glob.glob(os.path.join(app_dir,'*/plugin_%s/*' % plugin_name))
-        for file in files1+files2:
-            plugin_tarball.add(file, arcname=file[len(app_dir)+1:])
+        files1 = glob.glob(
+            os.path.join(app_dir, '*/plugin_%s.*' % plugin_name))
+        files2 = glob.glob(
+            os.path.join(app_dir, '*/plugin_%s/*' % plugin_name))
+        for file in files1 + files2:
+            plugin_tarball.add(file, arcname=file[len(app_dir) + 1:])
     finally:
         plugin_tarball.close()
 
@@ -279,18 +318,19 @@ def w2p_unpack_plugin(filename, path, delete_tar=True):
     filename = abspath(filename)
     path = abspath(path)
     if not os.path.basename(filename).startswith('web2py.plugin.'):
-        raise Exception, "Not a web2py plugin"
-    w2p_unpack(filename,path,delete_tar)
+        raise Exception("Not a web2py plugin")
+    w2p_unpack(filename, path, delete_tar)
 
 
-def tar_compiled(file, dir, expression='^.+$'):
-    """
-    used to tar a compiled application.
-    the content of models, views, controllers is not stored in the tar file.
+def tar_compiled(file, dir, expression='^.+$',
+                 exclude_content_from=None):
+    """Used to tar a compiled application.
+    The content of models, views, controllers is not stored in the tar file.
     """
 
     tar = tarfile.TarFile(file, 'w')
-    for file in listdir(dir, expression, add_dirs=True):
+    for file in listdir(dir, expression, add_dirs=True,
+                        exclude_content_from=exclude_content_from):
         filename = os.path.join(dir, file)
         if os.path.islink(filename):
             continue
@@ -306,37 +346,60 @@ def tar_compiled(file, dir, expression='^.+$'):
         tar.add(filename, file, False)
     tar.close()
 
+
 def up(path):
     return os.path.dirname(os.path.normpath(path))
 
 
 def get_session(request, other_application='admin'):
-    """ checks that user is authorized to access other_application"""
+    """Checks that user is authorized to access other_application"""
     if request.application == other_application:
         raise KeyError
     try:
         session_id = request.cookies['session_id_' + other_application].value
-        osession = storage.load_storage(os.path.join(
-                up(request.folder), other_application, 'sessions', session_id))
+        session_filename = os.path.join(
+            up(request.folder), other_application, 'sessions', session_id)
+        if not os.path.exists(session_filename):
+            session_filename = generate(session_filename)
+        osession = storage.load_storage(session_filename)
     except Exception, e:
         osession = storage.Storage()
     return osession
 
 
-def check_credentials(request, other_application='admin', expiration = 60*60):
-    """ checks that user is authorized to access other_application"""
+def set_session(request, session, other_application='admin'):
+    """Checks that user is authorized to access other_application"""
+    if request.application == other_application:
+        raise KeyError
+    session_id = request.cookies['session_id_' + other_application].value
+    session_filename = os.path.join(
+        up(request.folder), other_application, 'sessions', session_id)
+    storage.save_storage(session, session_filename)
+
+
+def check_credentials(request, other_application='admin',
+                      expiration=60 * 60, gae_login=True):
+    """Checks that user is authorized to access other_application"""
     if request.env.web2py_runtime_gae:
         from google.appengine.api import users
         if users.is_current_user_admin():
             return True
-        else:
+        elif gae_login:
             login_html = '<a href="%s">Sign in with your google account</a>.' \
                 % users.create_login_url(request.env.path_info)
             raise HTTP(200, '<html><body>%s</body></html>' % login_html)
+        else:
+            return False
     else:
-        dt = time.time() - expiration
+        t0 = time.time()
+        dt = t0 - expiration
         s = get_session(request, other_application)
-        return (s.authorized and s.last_time and s.last_time > dt)
+        r = (s.authorized and s.last_time and s.last_time > dt)
+        if r:
+            s.last_time = t0
+            set_session(request, s, other_application)
+        return r
+
 
 def fix_newlines(path):
     regex = re.compile(r'''(\r
@@ -348,12 +411,13 @@ def fix_newlines(path):
         if wdata != rdata:
             write_file(filename, wdata, 'wb')
 
+
 def copystream(
     src,
     dest,
     size,
     chunk_size=10 ** 5,
-    ):
+):
     """
     this is here because I think there is a bug in shutil.copyfileobj
     """
@@ -379,15 +443,20 @@ def make_fake_file_like_object():
     class LogFile(object):
         def write(self, value):
             pass
+
         def close(self):
             pass
     return LogFile()
 
 
-from settings import global_settings # we need to import settings here because
-                                     # settings imports fileutils too
+from settings import global_settings  # we need to import settings here because
+                                      # settings imports fileutils too
+
+
 def abspath(*relpath, **base):
-    "convert relative path to absolute path based (by default) on applications_parent"
+    """Converts relative path to absolute path based (by default) on
+    applications_parent
+    """
     path = os.path.join(*relpath)
     gluon = base.get('gluon', False)
     if os.path.isabs(path):
@@ -395,6 +464,3 @@ def abspath(*relpath, **base):
     if gluon:
         return os.path.join(global_settings.gluon_parent, path)
     return os.path.join(global_settings.applications_parent, path)
-
-
-
