@@ -10,29 +10,30 @@ import errno
 import socket
 import logging
 import platform
-import traceback
 
 # Define Constants
-VERSION = '1.2.5'
+VERSION = '1.2.6'
 SERVER_NAME = socket.gethostname()
 SERVER_SOFTWARE = 'Rocket %s' % VERSION
-HTTP_SERVER_SOFTWARE = '%s Python/%s' % (SERVER_SOFTWARE, sys.version.split(' ')[0])
+HTTP_SERVER_SOFTWARE = '%s Python/%s' % (
+    SERVER_SOFTWARE, sys.version.split(' ')[0])
 BUF_SIZE = 16384
-SOCKET_TIMEOUT = 10 # in secs
-THREAD_STOP_CHECK_INTERVAL = 1 # in secs, How often should threads check for a server stop message?
-IS_JYTHON = platform.system() == 'Java' # Handle special cases for Jython
+SOCKET_TIMEOUT = 10  # in secs
+THREAD_STOP_CHECK_INTERVAL = 1  # in secs, How often should threads check for a server stop message?
+IS_JYTHON = platform.system() == 'Java'  # Handle special cases for Jython
 IGNORE_ERRORS_ON_CLOSE = set([errno.ECONNABORTED, errno.ECONNRESET])
 DEFAULT_LISTEN_QUEUE_SIZE = 5
 DEFAULT_MIN_THREADS = 10
 DEFAULT_MAX_THREADS = 0
-DEFAULTS = dict(LISTEN_QUEUE_SIZE = DEFAULT_LISTEN_QUEUE_SIZE,
-                MIN_THREADS = DEFAULT_MIN_THREADS,
-                MAX_THREADS = DEFAULT_MAX_THREADS)
+DEFAULTS = dict(LISTEN_QUEUE_SIZE=DEFAULT_LISTEN_QUEUE_SIZE,
+                MIN_THREADS=DEFAULT_MIN_THREADS,
+                MAX_THREADS=DEFAULT_MAX_THREADS)
 
 PY3K = sys.version_info[0] > 2
 
+
 class NullHandler(logging.Handler):
-    "A Logging handler to prevent library errors."
+    """A Logging handler to prevent library errors."""
     def emit(self, record):
         pass
 
@@ -77,8 +78,8 @@ __all__ = ['VERSION', 'SERVER_SOFTWARE', 'HTTP_SERVER_SOFTWARE', 'BUF_SIZE',
            'IS_JYTHON', 'IGNORE_ERRORS_ON_CLOSE', 'DEFAULTS', 'PY3K', 'b', 'u',
            'Rocket', 'CherryPyWSGIServer', 'SERVER_NAME', 'NullHandler']
 
-# Monolithic build...end of module: rocket\__init__.py
-# Monolithic build...start of module: rocket\connection.py
+# Monolithic build...end of module: rocket/__init__.py
+# Monolithic build...start of module: rocket/connection.py
 
 # Import System Modules
 import sys
@@ -92,7 +93,8 @@ except ImportError:
 # Import Package Modules
 # package imports removed in monolithic build
 # TODO - This part is still very experimental.
-#from .filelike import FileLikeSocket
+# from .filelike import FileLikeSocket
+
 
 class Connection(object):
     __slots__ = [
@@ -115,7 +117,7 @@ class Connection(object):
     ]
 
     def __init__(self, sock_tuple, port, secure=False):
-        self.client_addr, self.client_port = sock_tuple[1]
+        self.client_addr, self.client_port = sock_tuple[1][:2]
         self.server_port = port
         self.socket = sock_tuple[0]
         self.start_time = time.time()
@@ -130,7 +132,6 @@ class Connection(object):
 
         self.socket.settimeout(SOCKET_TIMEOUT)
 
-        self.sendall = self.socket.sendall
         self.shutdown = self.socket.shutdown
         self.fileno = self.socket.fileno
         self.setblocking = self.socket.setblocking
@@ -138,6 +139,26 @@ class Connection(object):
         self.send = self.socket.send
         self.makefile = self.socket.makefile
 
+        if sys.platform == 'darwin':
+            self.sendall = self._sendall_darwin
+        else:
+            self.sendall = self.socket.sendall
+
+    def _sendall_darwin(self, buf):
+        pending = len(buf)
+        offset = 0
+        while pending:
+            try:
+                sent = self.socket.send(buf[offset:])
+                pending -= sent
+                offset += sent
+            except socket.error:
+                import errno
+                info = sys.exc_info()
+                if info[1].args[0] != errno.EAGAIN:
+                    raise
+        return offset
+
 # FIXME - this is not ready for prime-time yet.
 #    def makefile(self, buf_size=BUF_SIZE):
 #        return FileLikeSocket(self, buf_size)
@@ -154,9 +175,8 @@ class Connection(object):
                     pass
         self.socket.close()
 
-
-# Monolithic build...end of module: rocket\connection.py
-# Monolithic build...start of module: rocket\filelike.py
+# Monolithic build...end of module: rocket/connection.py
+# Monolithic build...start of module: rocket/filelike.py
 
 # Import System Modules
 import socket
@@ -170,6 +190,7 @@ except ImportError:
 # Import Package Modules
 # package imports removed in monolithic build
 
+
 class FileLikeSocket(object):
     def __init__(self, conn, buf_size=BUF_SIZE):
         self.conn = conn
@@ -278,8 +299,8 @@ class FileLikeSocket(object):
         self.conn = None
         self.content_length = None
 
-# Monolithic build...end of module: rocket\filelike.py
-# Monolithic build...start of module: rocket\futures.py
+# Monolithic build...end of module: rocket/filelike.py
+# Monolithic build...start of module: rocket/futures.py
 
 # Import System Modules
 import time
@@ -317,13 +338,12 @@ class WSGIFuture(Future):
         else:
             return super(WSGIFuture, self).set_running_or_notify_cancel()
 
-
     def remember(self, name, lifespan=None):
         self._lifespan = lifespan or self._lifespan
 
         if name in self._mem_dict:
-            raise NameError('Cannot remember future by name "%s".  ' % name + \
-                            'A future already exists with that name.' )
+            raise NameError('Cannot remember future by name "%s".  ' % name +
+                            'A future already exists with that name.')
         self._name = name
         self._mem_dict[name] = self
 
@@ -334,6 +354,7 @@ class WSGIFuture(Future):
             del self._mem_dict[self._name]
             self._name = None
 
+
 class _WorkItem(object):
     def __init__(self, future, fn, args, kwargs):
         self.future = future
@@ -353,6 +374,7 @@ class _WorkItem(object):
         else:
             self.future.set_result(result)
 
+
 class WSGIExecutor(ThreadPoolExecutor):
     multithread = True
     multiprocess = False
@@ -366,7 +388,8 @@ class WSGIExecutor(ThreadPoolExecutor):
         if self._shutdown_lock.acquire():
             if self._shutdown:
                 self._shutdown_lock.release()
-                raise RuntimeError('Cannot schedule new futures after shutdown')
+                raise RuntimeError(
+                    'Cannot schedule new futures after shutdown')
 
             f = WSGIFuture(self.futures)
             w = _WorkItem(f, fn, args, kwargs)
@@ -378,8 +401,9 @@ class WSGIExecutor(ThreadPoolExecutor):
         else:
             return False
 
+
 class FuturesMiddleware(object):
-    "Futures middleware that adds a Futures Executor to the environment"
+    """Futures middleware that adds a Futures Executor to the environment"""
     def __init__(self, app, threads=5):
         self.app = app
         self.executor = WSGIExecutor(threads)
@@ -389,8 +413,8 @@ class FuturesMiddleware(object):
         environ["wsgiorg.futures"] = self.executor.futures
         return self.app(environ, start_response)
 
-# Monolithic build...end of module: rocket\futures.py
-# Monolithic build...start of module: rocket\listener.py
+# Monolithic build...end of module: rocket/futures.py
+# Monolithic build...start of module: rocket/listener.py
 
 # Import System Modules
 import os
@@ -405,11 +429,13 @@ try:
     has_ssl = True
 except ImportError:
     has_ssl = False
+
     class SSLError(socket.error):
         pass
 # Import Package Modules
 # package imports removed in monolithic build
 
+
 class Listener(Thread):
     """The Listener class is a class responsible for accepting connections
     and queuing them to be processed by a worker thread."""
@@ -433,7 +459,10 @@ class Listener(Thread):
         self.err_log.addHandler(NullHandler())
 
         # Build the socket
-        listener = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        if ':' in self.addr:
+            listener = socket.socket(socket.AF_INET6, socket.SOCK_STREAM)
+        else:
+            listener = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 
         if not listener:
             self.err_log.error("Failed to get socket.")
@@ -446,18 +475,18 @@ class Listener(Thread):
             elif not os.path.exists(interface[2]):
                 data = (interface[2], interface[0], interface[1])
                 self.err_log.error("Cannot find key file "
-                          "'%s'.  Cannot bind to %s:%s" % data)
+                                   "'%s'.  Cannot bind to %s:%s" % data)
                 return
             elif not os.path.exists(interface[3]):
                 data = (interface[3], interface[0], interface[1])
                 self.err_log.error("Cannot find certificate file "
-                          "'%s'.  Cannot bind to %s:%s" % data)
+                                   "'%s'.  Cannot bind to %s:%s" % data)
                 return
 
             if self.clientcert_req and not os.path.exists(interface[4]):
                 data = (interface[4], interface[0], interface[1])
                 self.err_log.error("Cannot find root ca certificate file "
-                          "'%s'.  Cannot bind to %s:%s" % data)
+                                   "'%s'.  Cannot bind to %s:%s" % data)
                 return
 
         # Set socket options
@@ -499,24 +528,22 @@ class Listener(Thread):
                 ca_certs = self.interface[4]
                 cert_reqs = ssl.CERT_OPTIONAL
                 sock = ssl.wrap_socket(sock,
-                                       keyfile = self.interface[2],
-                                       certfile = self.interface[3],
-                                       server_side = True,
-                                       cert_reqs = cert_reqs,
-                                       ca_certs = ca_certs,
-                                       ssl_version = ssl.PROTOCOL_SSLv23)
+                                       keyfile=self.interface[2],
+                                       certfile=self.interface[3],
+                                       server_side=True,
+                                       cert_reqs=cert_reqs,
+                                       ca_certs=ca_certs,
+                                       ssl_version=ssl.PROTOCOL_SSLv23)
             else:
                 sock = ssl.wrap_socket(sock,
-                                       keyfile = self.interface[2],
-                                       certfile = self.interface[3],
-                                       server_side = True,
-                                       ssl_version = ssl.PROTOCOL_SSLv23)
-
+                                       keyfile=self.interface[2],
+                                       certfile=self.interface[3],
+                                       server_side=True,
+                                       ssl_version=ssl.PROTOCOL_SSLv23)
         except SSLError:
             # Generally this happens when an HTTP request is received on a
             # secure socket. We don't do anything because it will be detected
             # by Worker and dealt with appropriately.
-            # self.err_log.error('SSL Error: %s' % traceback.format_exc())
             pass
 
         return sock
@@ -567,8 +594,9 @@ class Listener(Thread):
                                        self.secure))
 
             except socket.timeout:
-                # socket.timeout will be raised every THREAD_STOP_CHECK_INTERVAL
-                # seconds.  When that happens, we check if it's time to die.
+                # socket.timeout will be raised every
+                # THREAD_STOP_CHECK_INTERVAL seconds.  When that happens,
+                # we check if it's time to die.
 
                 if not self.ready:
                     if __debug__:
@@ -579,8 +607,8 @@ class Listener(Thread):
             except:
                 self.err_log.error(traceback.format_exc())
 
-# Monolithic build...end of module: rocket\listener.py
-# Monolithic build...start of module: rocket\main.py
+# Monolithic build...end of module: rocket/listener.py
+# Monolithic build...start of module: rocket/main.py
 
 # Import System Modules
 import sys
@@ -597,27 +625,24 @@ except ImportError:
 # Import Package Modules
 # package imports removed in monolithic build
 
-
-
-
-
 # Setup Logging
 log = logging.getLogger('Rocket')
 log.addHandler(NullHandler())
 
+
 class Rocket(object):
     """The Rocket class is responsible for handling threads and accepting and
     dispatching connections."""
 
     def __init__(self,
-                 interfaces = ('127.0.0.1', 8000),
-                 method = 'wsgi',
-                 app_info = None,
-                 min_threads = None,
-                 max_threads = None,
-                 queue_size = None,
-                 timeout = 600,
-                 handle_signals = True):
+                 interfaces=('127.0.0.1', 8000),
+                 method='wsgi',
+                 app_info=None,
+                 min_threads=None,
+                 max_threads=None,
+                 queue_size=None,
+                 timeout=600,
+                 handle_signals=True):
 
         self.handle_signals = handle_signals
         self.startstop_lock = Lock()
@@ -650,15 +675,16 @@ class Rocket(object):
         self.active_queue = Queue()
 
         self._threadpool = ThreadPool(get_method(method),
-                                      app_info = app_info,
-                                      active_queue = self.active_queue,
-                                      monitor_queue = self.monitor_queue,
-                                      min_threads = min_threads,
-                                      max_threads = max_threads)
+                                      app_info=app_info,
+                                      active_queue=self.active_queue,
+                                      monitor_queue=self.monitor_queue,
+                                      min_threads=min_threads,
+                                      max_threads=max_threads)
 
         # Build our socket listeners
-        self.listeners = [Listener(i, queue_size, self.active_queue) for i in self.interfaces]
-        for ndx in range(len(self.listeners)-1, 0, -1):
+        self.listeners = [Listener(
+            i, queue_size, self.active_queue) for i in self.interfaces]
+        for ndx in range(len(self.listeners) - 1, 0, -1):
             if not self.listeners[ndx].ready:
                 del self.listeners[ndx]
 
@@ -705,7 +731,8 @@ class Rocket(object):
             str_extract = lambda l: (l.addr, l.port, l.secure and '*' or '')
 
             msg = 'Listening on sockets: '
-            msg += ', '.join(['%s:%i%s' % str_extract(l) for l in self.listeners])
+            msg += ', '.join(
+                ['%s:%i%s' % str_extract(l) for l in self.listeners])
             log.info(msg)
 
             for l in self.listeners:
@@ -730,7 +757,7 @@ class Rocket(object):
 
         return self.stop()
 
-    def stop(self, stoplogging = False):
+    def stop(self, stoplogging=False):
         log.info('Stopping %s' % SERVER_SOFTWARE)
 
         self.startstop_lock.acquire()
@@ -773,26 +800,27 @@ class Rocket(object):
         self.stop()
         self.start()
 
+
 def CherryPyWSGIServer(bind_addr,
                        wsgi_app,
-                       numthreads = 10,
-                       server_name = None,
-                       max = -1,
-                       request_queue_size = 5,
-                       timeout = 10,
-                       shutdown_timeout = 5):
+                       numthreads=10,
+                       server_name=None,
+                       max=-1,
+                       request_queue_size=5,
+                       timeout=10,
+                       shutdown_timeout=5):
     """ A Cherrypy wsgiserver-compatible wrapper. """
     max_threads = max
     if max_threads < 0:
         max_threads = 0
     return Rocket(bind_addr, 'wsgi', {'wsgi_app': wsgi_app},
-                  min_threads = numthreads,
-                  max_threads = max_threads,
-                  queue_size = request_queue_size,
-                  timeout = timeout)
+                  min_threads=numthreads,
+                  max_threads=max_threads,
+                  queue_size=request_queue_size,
+                  timeout=timeout)
 
-# Monolithic build...end of module: rocket\main.py
-# Monolithic build...start of module: rocket\monitor.py
+# Monolithic build...end of module: rocket/main.py
+# Monolithic build...start of module: rocket/monitor.py
 
 # Import System Modules
 import time
@@ -803,6 +831,7 @@ from threading import Thread
 # Import Package Modules
 # package imports removed in monolithic build
 
+
 class Monitor(Thread):
     # Monitor worker class.
 
@@ -926,8 +955,10 @@ class Monitor(Thread):
                 for c in stale:
                     if __debug__:
                         # "EXPR and A or B" kept for Py2.4 compatibility
-                        data = (c.client_addr, c.server_port, c.ssl and '*' or '')
-                        self.log.debug('Flushing stale connection: %s:%i%s' % data)
+                        data = (
+                            c.client_addr, c.server_port, c.ssl and '*' or '')
+                        self.log.debug(
+                            'Flushing stale connection: %s:%i%s' % data)
 
                     self.connections.remove(c)
                     list_changed = True
@@ -940,7 +971,6 @@ class Monitor(Thread):
             # Dynamically resize the threadpool to adapt to our changing needs.
             self._threadpool.dynamic_resize()
 
-
     def stop(self):
         self.active = False
 
@@ -971,8 +1001,8 @@ class Monitor(Thread):
         # Place a None sentry value to cause the monitor to die.
         self.monitor_queue.put(None)
 
-# Monolithic build...end of module: rocket\monitor.py
-# Monolithic build...start of module: rocket\threadpool.py
+# Monolithic build...end of module: rocket/monitor.py
+# Monolithic build...start of module: rocket/threadpool.py
 
 # Import System Modules
 import logging
@@ -984,6 +1014,7 @@ import logging
 log = logging.getLogger('Rocket.Errors.ThreadPool')
 log.addHandler(NullHandler())
 
+
 class ThreadPool:
     """The ThreadPool class is a container class for all the worker threads. It
     manages the number of actively running threads."""
@@ -1011,7 +1042,7 @@ class ThreadPool:
         self.alive = False
 
         # TODO - Optimize this based on some real-world usage data
-        self.grow_threshold = int(max_threads/10) + 2
+        self.grow_threshold = int(max_threads / 10) + 2
 
         if not isinstance(app_info, dict):
             app_info = dict()
@@ -1056,10 +1087,10 @@ class ThreadPool:
             self.app_info['executor'].shutdown(wait=False)
 
         # Give them the gun
-        #active_threads = [t for t in self.threads if t.isAlive()]
-        #while active_threads:
-        #    t = active_threads.pop()
-        #    t.kill()
+        # active_threads = [t for t in self.threads if t.isAlive()]
+        # while active_threads:
+        #     t = active_threads.pop()
+        #     t.kill()
 
         # Wait until they pull the trigger
         for t in self.threads:
@@ -1133,8 +1164,8 @@ class ThreadPool:
 
                 self.grow(queueSize)
 
-# Monolithic build...end of module: rocket\threadpool.py
-# Monolithic build...start of module: rocket\worker.py
+# Monolithic build...end of module: rocket/threadpool.py
+# Monolithic build...start of module: rocket/worker.py
 
 # Import System Modules
 import re
@@ -1179,21 +1210,23 @@ re_REQUEST_LINE = re.compile(r"""^
     (?P<host>[^/]+)                                          # Host
 )? #
 (?P<path>(\*|/[^ \?]*))                                      # Path
-(\? (?P<query_string>[^ ]+))?                                # Query String
+(\? (?P<query_string>[^ ]*))?                                # Query String
 \                                                            # (single space)
 (?P<protocol>HTTPS?/1\.[01])                                 # Protocol
 $
 """, re.X)
 LOG_LINE = '%(client_ip)s - "%(request_line)s" - %(status)s %(size)s'
 RESPONSE = '''\
-HTTP/1.1 %s
+%s %s
 Content-Length: %i
 Content-Type: %s
 
 %s
 '''
 if IS_JYTHON:
-    HTTP_METHODS = set(['OPTIONS', 'GET', 'HEAD', 'POST', 'PUT', 'DELETE', 'TRACE', 'CONNECT'])
+    HTTP_METHODS = set(['OPTIONS', 'GET', 'HEAD', 'POST', 'PUT',
+                        'DELETE', 'TRACE', 'CONNECT'])
+
 
 class Worker(Thread):
     """The Worker class is a base class responsible for receiving connections
@@ -1217,13 +1250,14 @@ class Worker(Thread):
         self.status = "200 OK"
         self.closeConnection = True
         self.request_line = ""
+        self.protocol = 'HTTP/1.1'
 
         # Request Log
         self.req_log = logging.getLogger('Rocket.Requests')
         self.req_log.addHandler(NullHandler())
 
         # Error Log
-        self.err_log = logging.getLogger('Rocket.Errors.'+self.getName())
+        self.err_log = logging.getLogger('Rocket.Errors.' + self.getName())
         self.err_log.addHandler(NullHandler())
 
     def _handleError(self, typ, val, tb):
@@ -1301,25 +1335,19 @@ class Worker(Thread):
                     self.err_log.debug('Serving a request')
                 try:
                     self.run_app(conn)
-                    log_info = dict(client_ip = conn.client_addr,
-                                    time = datetime.now().strftime('%c'),
-                                    status = self.status.split(' ')[0],
-                                    size = self.size,
-                                    request_line = self.request_line)
-                    self.req_log.info(LOG_LINE % log_info)
                 except:
                     exc = sys.exc_info()
                     handled = self._handleError(*exc)
                     if handled:
                         break
-                    else:
-                        if self.request_line:
-                            log_info = dict(client_ip = conn.client_addr,
-                                            time = datetime.now().strftime('%c'),
-                                            status = self.status.split(' ')[0],
-                                            size = self.size,
-                                            request_line = self.request_line + ' - not stopping')
-                            self.req_log.info(LOG_LINE % log_info)
+                finally:
+                    if self.request_line:
+                        log_info = dict(client_ip=conn.client_addr,
+                                        time=datetime.now().strftime('%c'),
+                                        status=self.status.split(' ')[0],
+                                        size=self.size,
+                                        request_line=self.request_line)
+                        self.req_log.info(LOG_LINE % log_info)
 
                 if self.closeConnection:
                     try:
@@ -1337,7 +1365,8 @@ class Worker(Thread):
 
     def send_response(self, status):
         stat_msg = status.split(' ', 1)[1]
-        msg = RESPONSE % (status,
+        msg = RESPONSE % (self.protocol,
+                          status,
                           len(stat_msg),
                           'text/plain',
                           stat_msg)
@@ -1345,23 +1374,12 @@ class Worker(Thread):
             self.conn.sendall(b(msg))
         except socket.timeout:
             self.closeConnection = True
-            self.err_log.error(
-                'Tried to send "%s" to client but received timeout error'
-                % status)
+            msg = 'Tried to send "%s" to client but received timeout error'
+            self.err_log.error(msg % status)
         except socket.error:
             self.closeConnection = True
-            self.err_log.error(
-                'Tried to send "%s" to client but received socket error'
-                % status)
-
-    #def kill(self):
-    #    if self.isAlive() and hasattr(self, 'conn'):
-    #        try:
-    #            self.conn.shutdown(socket.SHUT_RDWR)
-    #        except socket.error:
-    #            info = sys.exc_info()
-    #            if info[1].args[0] != socket.EBADF:
-    #                self.err_log.debug('Error on shutdown: '+str(info))
+            msg = 'Tried to send "%s" to client but received socket error'
+            self.err_log.error(msg % status)
 
     def read_request_line(self, sock_file):
         self.request_line = ''
@@ -1380,15 +1398,18 @@ class Worker(Thread):
                 if PY3K:
                     d = d.decode('ISO-8859-1')
         except socket.timeout:
-            raise SocketTimeout("Socket timed out before request.")
+            raise SocketTimeout('Socket timed out before request.')
         except TypeError:
-            raise SocketClosed("ssl bug caused closer of socket, upgrade to python 2.7")
+            raise SocketClosed(
+                'SSL bug caused closure of socket.  See '
+                '"https://groups.google.com/d/topic/web2py/P_Gw0JxWzCs".')
 
         d = d.strip()
 
         if not d:
             if __debug__:
-                self.err_log.debug('Client did not send a recognizable request.')
+                self.err_log.debug(
+                    'Client did not send a recognizable request.')
             raise SocketClosed('Client closed socket.')
 
         self.request_line = d
@@ -1408,12 +1429,14 @@ class Worker(Thread):
             raise BadRequest
 
         req = match.groupdict()
-        for k,v in req.iteritems():
+        for k, v in req.iteritems():
             if not v:
                 req[k] = ""
             if k == 'path':
-                req['path'] = r'%2F'.join([unquote(x) for x in re_SLASH.split(v)])
+                req['path'] = r'%2F'.join(
+                    [unquote(x) for x in re_SLASH.split(v)])
 
+        self.protocol = req['protocol']
         return req
 
     def _read_request_line_jython(self, d):
@@ -1421,15 +1444,15 @@ class Worker(Thread):
         try:
             method, uri, proto = d.split(' ')
             if not proto.startswith('HTTP') or \
-               proto[-3:] not in ('1.0', '1.1') or \
-               method not in HTTP_METHODS:
+                    proto[-3:] not in ('1.0', '1.1') or \
+                    method not in HTTP_METHODS:
                 self.send_response('400 Bad Request')
                 raise BadRequest
         except ValueError:
             self.send_response('400 Bad Request')
             raise BadRequest
 
-        req = dict(method=method, protocol = proto)
+        req = dict(method=method, protocol=proto)
         scheme = ''
         host = ''
         if uri == '*' or uri.startswith('/'):
@@ -1454,48 +1477,60 @@ class Worker(Thread):
                    host=host)
         return req
 
-
-    def read_headers(self, sock_file, environ):
+    def read_headers(self, sock_file):
         try:
+            headers = dict()
             lname = None
+            lval = None
             while True:
                 l = sock_file.readline()
+
                 if PY3K:
                     try:
                         l = str(l, 'ISO-8859-1')
                     except UnicodeDecodeError:
-                        self.err_log.warning('Invalid request header: '+repr(l))
+                        self.err_log.warning(
+                            'Client sent invalid header: ' + repr(l))
 
-                if l.strip().replace('\0','') == '':
+                if l.strip().replace('\0', '') == '':
                     break
-                elif l[0] in ' \t' and lname:
+
+                if l[0] in ' \t' and lname:
                     # Some headers take more than one line
-                    environ[lname] += ' ' + l.strip()
+                    lval += ' ' + l.strip()
                 else:
                     # HTTP header values are latin-1 encoded
                     l = l.split(':', 1)
                     # HTTP header names are us-ascii encoded
 
-                    lname = str('HTTP_'+l[0].strip().upper().replace('-', '_'))
-                    lval = str(l[-1].strip())
-                    environ[lname] = lval
+                    lname = l[0].strip().upper().replace('-', '_')
+                    lval = l[-1].strip()
+
+                headers[str(lname)] = str(lval)
 
         except socket.timeout:
             raise SocketTimeout("Socket timed out before request.")
 
+        return headers
+
+
 class SocketTimeout(Exception):
-    "Exception for when a socket times out between requests."
+    """Exception for when a socket times out between requests."""
     pass
 
+
 class BadRequest(Exception):
-    "Exception for when a client sends an incomprehensible request."
+    """Exception for when a client sends an incomprehensible request."""
     pass
 
+
 class SocketClosed(Exception):
-    "Exception for when a socket is closed by the client."
+    """Exception for when a socket is closed by the client."""
     pass
 
+
 class ChunkedReader(object):
+
     def __init__(self, sock_file):
         self.stream = sock_file
         self.chunk_size = 0
@@ -1542,12 +1577,16 @@ class ChunkedReader(object):
     def readlines(self):
         yield self.readline()
 
+
 def get_method(method):
     methods = dict(wsgi=WSGIWorker)
     return methods[method.lower()]
 
-# Monolithic build...end of module: rocket\worker.py
-# Monolithic build...start of module: rocket\methods\wsgi.py
+# Monolithic build...end of module: rocket/worker.py
+# Monolithic build...start of module: rocket/methods/__init__.py
+
+# Monolithic build...end of module: rocket/methods/__init__.py
+# Monolithic build...start of module: rocket/methods/wsgi.py
 
 # Import System Modules
 import sys
@@ -1558,8 +1597,6 @@ from wsgiref.util import FileWrapper
 # Import Package Modules
 # package imports removed in monolithic build
 
-
-
 if PY3K:
     from email.utils import formatdate
 else:
@@ -1578,6 +1615,7 @@ BASE_ENV = {'SERVER_NAME': SERVER_NAME,
             'wsgi.file_wrapper': FileWrapper
             }
 
+
 class WSGIWorker(Worker):
     def __init__(self, *args, **kwargs):
         """Builds some instance variables that will last the life of the
@@ -1588,9 +1626,10 @@ class WSGIWorker(Worker):
             multithreaded = self.app_info.get('max_threads') != 1
         else:
             multithreaded = False
-        self.base_environ = dict({'SERVER_SOFTWARE': self.app_info['server_software'],
-                                  'wsgi.multithread': multithreaded,
-                                  })
+        self.base_environ = dict(
+            {'SERVER_SOFTWARE': self.app_info['server_software'],
+             'wsgi.multithread': multithreaded,
+             })
         self.base_environ.update(BASE_ENV)
 
         # Grab our application
@@ -1614,15 +1653,16 @@ class WSGIWorker(Worker):
         environ = self.base_environ.copy()
 
         # Grab the headers
-        self.read_headers(sock_file,environ)
+        for k, v in self.read_headers(sock_file).iteritems():
+            environ[str('HTTP_' + k)] = v
 
         # Add CGI Variables
-        environ['SERVER_PORT'] = str(conn.server_port)
-        environ['REMOTE_PORT'] = str(conn.client_port)
-        environ['REMOTE_ADDR'] = str(conn.client_addr)
         environ['REQUEST_METHOD'] = request['method']
         environ['PATH_INFO'] = request['path']
         environ['SERVER_PROTOCOL'] = request['protocol']
+        environ['SERVER_PORT'] = str(conn.server_port)
+        environ['REMOTE_PORT'] = str(conn.client_port)
+        environ['REMOTE_ADDR'] = str(conn.client_addr)
         environ['QUERY_STRING'] = request['query_string']
         if 'HTTP_CONTENT_LENGTH' in environ:
             environ['CONTENT_LENGTH'] = environ['HTTP_CONTENT_LENGTH']
@@ -1636,16 +1676,14 @@ class WSGIWorker(Worker):
         if conn.ssl:
             environ['wsgi.url_scheme'] = 'https'
             environ['HTTPS'] = 'on'
-        else:
-            environ['wsgi.url_scheme'] = 'http'
-
-        if conn.ssl:
             try:
                 peercert = conn.socket.getpeercert(binary_form=True)
                 environ['SSL_CLIENT_RAW_CERT'] = \
                     peercert and ssl.DER_cert_to_PEM_cert(peercert)
-            except Exception,e:
-                print e
+            except Exception:
+                print sys.exc_info()[1]
+        else:
+            environ['wsgi.url_scheme'] = 'http'
 
         if environ.get('HTTP_TRANSFER_ENCODING', '') == 'chunked':
             environ['wsgi.input'] = ChunkedReader(sock_file)
@@ -1658,36 +1696,36 @@ class WSGIWorker(Worker):
         h_set = self.header_set
 
         # Does the app want us to send output chunked?
-        self.chunked = h_set.get('transfer-encoding', '').lower() == 'chunked'
+        self.chunked = h_set.get('Transfer-Encoding', '').lower() == 'chunked'
 
         # Add a Date header if it's not there already
-        if not 'date' in h_set:
+        if not 'Date' in h_set:
             h_set['Date'] = formatdate(usegmt=True)
 
         # Add a Server header if it's not there already
-        if not 'server' in h_set:
+        if not 'Server' in h_set:
             h_set['Server'] = HTTP_SERVER_SOFTWARE
 
-        if 'content-length' in h_set:
-            self.size = int(h_set['content-length'])
+        if 'Content-Length' in h_set:
+            self.size = int(h_set['Content-Length'])
         else:
             s = int(self.status.split(' ')[0])
-            if s < 200 or s not in (204, 205, 304):
-                if not self.chunked:
-                    if sections == 1:
-                        # Add a Content-Length header if it's not there already
-                        h_set['Content-Length'] = str(len(data))
-                        self.size = len(data)
-                    else:
-                        # If they sent us more than one section, we blow chunks
-                        h_set['Transfer-Encoding'] = 'Chunked'
-                        self.chunked = True
-                        if __debug__:
-                            self.err_log.debug('Adding header...'
-                                               'Transfer-Encoding: Chunked')
+            if (s < 200 or s not in (204, 205, 304)) and not self.chunked:
+                if sections == 1 or self.protocol != 'HTTP/1.1':
+                    # Add a Content-Length header because it's not there
+                    self.size = len(data)
+                    h_set['Content-Length'] = str(self.size)
+                else:
+                    # If they sent us more than one section, we blow chunks
+                    h_set['Transfer-Encoding'] = 'Chunked'
+                    self.chunked = True
+                    if __debug__:
+                        self.err_log.debug('Adding header...'
+                                           'Transfer-Encoding: Chunked')
 
-        if 'connection' not in h_set:
-            # If the application did not provide a connection header, fill it in
+        if 'Connection' not in h_set:
+            # If the application did not provide a connection header,
+            # fill it in
             client_conn = self.environ.get('HTTP_CONNECTION', '').lower()
             if self.environ['SERVER_PROTOCOL'] == 'HTTP/1.1':
                 # HTTP = 1.1 defaults to keep-alive connections
@@ -1696,11 +1734,12 @@ class WSGIWorker(Worker):
                 else:
                     h_set['Connection'] = 'keep-alive'
             else:
-                # HTTP < 1.1 supports keep-alive but it's quirky so we don't support it
+                # HTTP < 1.1 supports keep-alive but it's quirky
+                # so we don't support it
                 h_set['Connection'] = 'close'
 
         # Close our connection if we need to.
-        self.closeConnection = h_set.get('connection', '').lower() == 'close'
+        self.closeConnection = h_set.get('Connection', '').lower() == 'close'
 
         # Build our output headers
         header_data = HEADER_RESPONSE % (self.status, str(h_set))
@@ -1732,6 +1771,8 @@ class WSGIWorker(Worker):
                     self.conn.sendall(b('%x\r\n%s\r\n' % (len(data), data)))
                 else:
                     self.conn.sendall(data)
+            except socket.timeout:
+                self.closeConnection = True
             except socket.error:
                 # But some clients will close the connection before that
                 # resulting in a socket error.
@@ -1809,75 +1850,23 @@ class WSGIWorker(Worker):
                 if data:
                     self.write(data, sections)
 
-            if self.chunked:
-                # If chunked, send our final chunk length
-                self.conn.sendall(b('0\r\n\r\n'))
-            elif not self.headers_sent:
+            if not self.headers_sent:
                 # Send headers if the body was empty
                 self.send_headers('', sections)
 
+            if self.chunked and self.request_method != 'HEAD':
+                # If chunked, send our final chunk length
+                self.conn.sendall(b('0\r\n\r\n'))
+
         # Don't capture exceptions here.  The Worker class handles
         # them appropriately.
         finally:
             if __debug__:
                 self.err_log.debug('Finally closing output and sock_file')
 
-            if hasattr(output,'close'):
+            if hasattr(output, 'close'):
                 output.close()
 
             sock_file.close()
 
-# Monolithic build...end of module: rocket\methods\wsgi.py
-
-#
-# the following code is not part of Rocket but was added in web2py for testing purposes
-#
-
-def demo_app(environ, start_response):
-    global static_folder
-    import os
-    types = {'htm': 'text/html','html': 'text/html','gif': 'image/gif',
-             'jpg': 'image/jpeg','png': 'image/png','pdf': 'applications/pdf'}
-    if static_folder:
-        if not static_folder.startswith('/'):
-            static_folder = os.path.join(os.getcwd(),static_folder)
-        path = os.path.join(static_folder, environ['PATH_INFO'][1:] or 'index.html')
-        type = types.get(path.split('.')[-1],'text')
-        if os.path.exists(path):
-            try:
-                data = open(path,'rb').read()
-                start_response('200 OK', [('Content-Type', type)])
-            except IOError:
-                start_response('404 NOT FOUND', [])
-                data = '404 NOT FOUND'
-        else:
-            start_response('500 INTERNAL SERVER ERROR', [])
-            data = '500 INTERNAL SERVER ERROR'
-    else:
-        start_response('200 OK', [('Content-Type', 'text/html')])
-        data = '<html><body><h1>Hello from Rocket Web Server</h1></body></html>'
-    return [data]
-
-def demo():
-    from optparse import OptionParser
-    parser = OptionParser()
-    parser.add_option("-i", "--ip", dest="ip",default="127.0.0.1",
-                      help="ip address of the network interface")
-    parser.add_option("-p", "--port", dest="port",default="8000",
-                      help="post where to run web server")
-    parser.add_option("-s", "--static", dest="static",default=None,
-                      help="folder containing static files")
-    (options, args) = parser.parse_args()
-    global static_folder
-    static_folder = options.static
-    print 'Rocket running on %s:%s' % (options.ip, options.port)
-    r=Rocket((options.ip,int(options.port)),'wsgi', {'wsgi_app':demo_app})
-    r.start()
-
-if __name__=='__main__':
-    demo()
-
-
-
-
-
+# Monolithic build...end of module: rocket/methods/wsgi.py
