@@ -1,14 +1,15 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
-This file is part of the web2py Web Framework
-Copyrighted by Massimo Di Pierro <mdipierro@cs.depaul.edu>
-License: LGPLv3 (http://www.gnu.org/licenses/lgpl.html)
+| This file is part of the web2py Web Framework
+| Copyrighted by Massimo Di Pierro <mdipierro@cs.depaul.edu>
+| License: LGPLv3 (http://www.gnu.org/licenses/lgpl.html)
 """
 
 import os
 import sys
-import socket
 import platform
-from storage import Storage
+from gluon.storage import Storage
 
 global_settings = Storage()
 settings = global_settings  # legacy compatibility
@@ -29,7 +30,7 @@ global_settings.app_folders = set()
 global_settings.debugging = False
 
 global_settings.is_pypy = \
-    hasattr(platform,'python_implementation') and \
+    hasattr(platform, 'python_implementation') and \
     platform.python_implementation() == 'PyPy'
 
 global_settings.is_jython = \
@@ -37,4 +38,5 @@ global_settings.is_jython = \
     hasattr(sys, 'JYTHON_JAR') or \
     str(sys.copyright).find('Jython') > 0
 
-
+global_settings.is_source = os.path.exists(os.path.join(
+        global_settings.gluon_parent, 'web2py.py'))
