@@ -2,47 +2,54 @@
 # -*- coding: utf-8 -*-
 
 """
-This file is part of the web2py Web Framework (Copyrighted, 2007-2011).
-License: LGPLv3 (http://www.gnu.org/licenses/lgpl.html)
+| This file is part of the web2py Web Framework
+| License: LGPLv3 (http://www.gnu.org/licenses/lgpl.html)
+| Author: Thadeus Burgess
+| Contributors:
+| - Massimo Di Pierro for creating the original gluon/template.py
+| - Jonathan Lundell for extensively testing the regex on Jython.
+| - Limodou (creater of uliweb) who inspired the block-element support for web2py.
 
-Author: Thadeus Burgess
-
-Contributors:
-
-- Thank you to Massimo Di Pierro for creating the original gluon/template.py
-- Thank you to Jonathan Lundell for extensively testing the regex on Jython.
-- Thank you to Limodou (creater of uliweb) who inspired the block-element support for web2py.
+Templating syntax
+------------------
 """
 
 import os
 import cgi
-import cStringIO
 import logging
 from re import compile, sub, escape, DOTALL
+try:
+    import cStringIO as StringIO
+except:
+    from io import StringIO
+
 try:
     # have web2py
-    from restricted import RestrictedError
-    from globals import current
+    from gluon.restricted import RestrictedError
+    from gluon.globals import current
 except ImportError:
     # do not have web2py
     current = None
-    def RestrictedError(a,b,c):
-        logging.error(str(a)+':'+str(b)+':'+str(c))
+
+    def RestrictedError(a, b, c):
+        logging.error(str(a) + ':' + str(b) + ':' + str(c))
         return RuntimeError
 
+
 class Node(object):
     """
     Basic Container Object
     """
-    def __init__(self, value = None, pre_extend = False):
+    def __init__(self, value=None, pre_extend=False):
         self.value = value
         self.pre_extend = pre_extend
 
     def __str__(self):
         return str(self.value)
 
+
 class SuperNode(Node):
-    def __init__(self, name = '', pre_extend = False):
+    def __init__(self, name='', pre_extend=False):
         self.name = name
         self.value = None
         self.pre_extend = pre_extend
@@ -57,7 +64,8 @@ class SuperNode(Node):
     def __repr__(self):
         return "%s->%s" % (self.name, self.value)
 
-def output_aux(node,blocks):
+
+def output_aux(node, blocks):
     # If we have a block level
     #   If we can override this block.
     #     Override block from vars.
@@ -66,8 +74,9 @@ def output_aux(node,blocks):
     return (blocks[node.name].output(blocks)
             if node.name in blocks else
             node.output(blocks)) \
-            if isinstance(node, BlockNode) \
-            else str(node)
+        if isinstance(node, BlockNode) \
+        else str(node)
+
 
 class BlockNode(Node):
     """
@@ -81,8 +90,9 @@ class BlockNode(Node):
         {{ block test }}
             This is default block test
         {{ end }}
+
     """
-    def __init__(self, name = '', pre_extend = False, delimiters = ('{{','}}')):
+    def __init__(self, name='', pre_extend=False, delimiters=('{{', '}}')):
         """
         name - Name of this Node.
         """
@@ -92,7 +102,7 @@ class BlockNode(Node):
         self.left, self.right = delimiters
 
     def __repr__(self):
-        lines = ['%sblock %s%s' % (self.left,self.name,self.right)]
+        lines = ['%sblock %s%s' % (self.left, self.name, self.right)]
         lines += [str(node) for node in self.nodes]
         lines.append('%send%s' % (self.left, self.right))
         return ''.join(lines)
@@ -101,16 +111,15 @@ class BlockNode(Node):
         """
         Get this BlockNodes content, not including child Nodes
         """
-        return ''.join(str(node) for node in self.nodes \
-                           if not isinstance(node, BlockNode))
+        return ''.join(str(node) for node in self.nodes
+                       if not isinstance(node, BlockNode))
 
     def append(self, node):
         """
-        Add an element to the nodes.
+        Adds an element to the nodes.
 
-        Keyword Arguments
-
-        - node -- Node object or string to append.
+        Args:
+            node: Node object or string to append.
         """
         if isinstance(node, str) or isinstance(node, Node):
             self.nodes.append(node)
@@ -119,56 +128,56 @@ class BlockNode(Node):
 
     def extend(self, other):
         """
-        Extend the list of nodes with another BlockNode class.
+        Extends the list of nodes with another BlockNode class.
 
-        Keyword Arguments
-
-        - other -- BlockNode or Content object to extend from.
+        Args:
+            other: BlockNode or Content object to extend from.
         """
         if isinstance(other, BlockNode):
             self.nodes.extend(other.nodes)
         else:
-            raise TypeError("Invalid type; must be instance of ``BlockNode``. %s" % other)
-
+            raise TypeError(
+                "Invalid type; must be instance of ``BlockNode``. %s" % other)
 
     def output(self, blocks):
         """
         Merges all nodes into a single string.
-        blocks -- Dictionary of blocks that are extending
-        from this template.
+
+        Args:
+            blocks: Dictionary of blocks that are extending from this template.
         """
-        return ''.join(output_aux(node,blocks) for node in self.nodes)
+        return ''.join(output_aux(node, blocks) for node in self.nodes)
+
 
 class Content(BlockNode):
     """
     Parent Container -- Used as the root level BlockNode.
 
     Contains functions that operate as such.
-    """
-    def __init__(self, name = "ContentBlock", pre_extend = False):
-        """
-        Keyword Arguments
 
-        name -- Unique name for this BlockNode
-        """
+    Args:
+        name: Unique name for this BlockNode
+    """
+    def __init__(self, name="ContentBlock", pre_extend=False):
         self.name = name
         self.nodes = []
         self.blocks = {}
         self.pre_extend = pre_extend
 
     def __str__(self):
-        return ''.join(output_aux(node,self.blocks) for node in self.nodes)
+        return ''.join(output_aux(node, self.blocks) for node in self.nodes)
 
-    def _insert(self, other, index = 0):
+    def _insert(self, other, index=0):
         """
         Inserts object at index.
         """
         if isinstance(other, (str, Node)):
             self.nodes.insert(index, other)
         else:
-            raise TypeError("Invalid type, must be instance of ``str`` or ``Node``.")
+            raise TypeError(
+                "Invalid type, must be instance of ``str`` or ``Node``.")
 
-    def insert(self, other, index = 0):
+    def insert(self, other, index=0):
         """
         Inserts object at index.
 
@@ -201,48 +210,53 @@ class Content(BlockNode):
             self.nodes.extend(other.nodes)
             self.blocks.update(other.blocks)
         else:
-            raise TypeError("Invalid type; must be instance of ``BlockNode``. %s" % other)
+            raise TypeError(
+                "Invalid type; must be instance of ``BlockNode``. %s" % other)
 
     def clear_content(self):
         self.nodes = []
 
-class TemplateParser(object):
 
-    default_delimiters = ('{{','}}')
+class TemplateParser(object):
+    """Parse all blocks
+
+    Args:
+        text: text to parse
+        context: context to parse in
+        path: folder path to templates
+        writer: string of writer class to use
+        lexers: dict of custom lexers to use.
+        delimiters: for example `('{{','}}')`
+        _super_nodes: a list of nodes to check for inclusion
+            this should only be set by "self.extend"
+            It contains a list of SuperNodes from a child
+            template that need to be handled.
+
+    """
+
+    default_delimiters = ('{{', '}}')
     r_tag = compile(r'(\{\{.*?\}\})', DOTALL)
 
     r_multiline = compile(r'(""".*?""")|(\'\'\'.*?\'\'\')', DOTALL)
 
     # These are used for re-indentation.
     # Indent + 1
-    re_block = compile('^(elif |else:|except:|except |finally:).*$',DOTALL)
-                      
+    re_block = compile('^(elif |else:|except:|except |finally:).*$', DOTALL)
+
     # Indent - 1
     re_unblock = compile('^(return|continue|break|raise)( .*)?$', DOTALL)
     # Indent - 1
     re_pass = compile('^pass( .*)?$', DOTALL)
 
     def __init__(self, text,
-                 name    = "ParserContainer",
-                 context = dict(),
-                 path    = 'views/',
-                 writer  = 'response.write',
-                 lexers  = {},
-                 delimiters = ('{{','}}'),
+                 name="ParserContainer",
+                 context=dict(),
+                 path='views/',
+                 writer='response.write',
+                 lexers={},
+                 delimiters=('{{', '}}'),
                  _super_nodes = [],
                  ):
-        """
-        text -- text to parse
-        context -- context to parse in
-        path -- folder path to templates
-        writer -- string of writer class to use
-        lexers -- dict of custom lexers to use.
-        delimiters -- for example ('{{','}}')
-        _super_nodes -- a list of nodes to check for inclusion
-                        this should only be set by "self.extend"
-                        It contains a list of SuperNodes from a child
-                        template that need to be handled.
-        """
 
         # Keep a root level name.
         self.name = name
@@ -265,18 +279,20 @@ class TemplateParser(object):
         self.context = context
 
         # allow optional alternative delimiters
-        self.delimiters = delimiters
+
         if delimiters != self.default_delimiters:
             escaped_delimiters = (escape(delimiters[0]),
                                   escape(delimiters[1]))
             self.r_tag = compile(r'(%s.*?%s)' % escaped_delimiters, DOTALL)
-        elif hasattr(context.get('response',None),'delimiters'):
+        elif hasattr(context.get('response', None), 'delimiters'):
             if context['response'].delimiters != self.default_delimiters:
+                delimiters = context['response'].delimiters
                 escaped_delimiters = (
-                    escape(context['response'].delimiters[0]),
-                    escape(context['response'].delimiters[1]))
+                    escape(delimiters[0]),
+                    escape(delimiters[1]))
                 self.r_tag = compile(r'(%s.*?%s)' % escaped_delimiters,
                                      DOTALL)
+        self.delimiters = delimiters
 
         # Create a root level Content that everything will go into.
         self.content = Content(name=name)
@@ -304,18 +320,18 @@ class TemplateParser(object):
 
     def to_string(self):
         """
-        Return the parsed template with correct indentation.
+        Returns the parsed template with correct indentation.
 
         Used to make it easier to port to python3.
         """
         return self.reindent(str(self.content))
 
     def __str__(self):
-        "Make sure str works exactly the same as python 3"
+        "Makes sure str works exactly the same as python 3"
         return self.to_string()
 
     def __unicode__(self):
-        "Make sure str works exactly the same as python 3"
+        "Makes sure str works exactly the same as python 3"
         return self.to_string()
 
     def reindent(self, text):
@@ -359,10 +375,10 @@ class TemplateParser(object):
                 k = k + credit - 1
 
             # We obviously can't have a negative indentation
-            k = max(k,0)
+            k = max(k, 0)
 
             # Add the indentation!
-            new_lines.append(' '*(4*k)+line)
+            new_lines.append(' ' * (4 * k) + line)
 
             # Bank account back to 0 again :(
             credit = 0
@@ -398,13 +414,13 @@ class TemplateParser(object):
 
     def _raise_error(self, message='', text=None):
         """
-        Raise an error using itself as the filename and textual content.
+        Raises an error using itself as the filename and textual content.
         """
         raise RestrictedError(self.name, text or self.text, message)
 
     def _get_file_text(self, filename):
         """
-        Attempt to open ``filename`` and retrieve its text.
+        Attempts to open ``filename`` and retrieve its text.
 
         This will use self.path to search for the file.
         """
@@ -416,12 +432,16 @@ class TemplateParser(object):
         # Allow Views to include other views dynamically
         context = self.context
         if current and not "response" in context:
-            context["response"] = getattr(current,'response',None)
+            context["response"] = getattr(current, 'response', None)
 
         # Get the filename; filename looks like ``"template.html"``.
         # We need to eval to remove the quotes and get the string type.
         filename = eval(filename, context)
 
+        # Allow empty filename for conditional extend and include directives.
+        if not filename:
+            return ''
+
         # Get the path of the file on the system.
         filepath = self.path and os.path.join(self.path, filename) or filename
 
@@ -437,25 +457,26 @@ class TemplateParser(object):
 
     def include(self, content, filename):
         """
-        Include ``filename`` here.
+        Includes ``filename`` here.
         """
         text = self._get_file_text(filename)
 
         t = TemplateParser(text,
-                           name    = filename,
-                           context = self.context,
-                           path    = self.path,
-                           writer  = self.writer,
-                           delimiters = self.delimiters)
+                           name=filename,
+                           context=self.context,
+                           path=self.path,
+                           writer=self.writer,
+                           delimiters=self.delimiters)
 
         content.append(t.content)
 
     def extend(self, filename):
         """
-        Extend ``filename``. Anything not declared in a block defined by the
-        parent will be placed in the parent templates ``{{include}}`` block.
+        Extends `filename`. Anything not declared in a block defined by the
+        parent will be placed in the parent templates `{{include}}` block.
         """
-        text = self._get_file_text(filename)
+        # If no filename, create a dummy layout with only an {{include}}.
+        text = self._get_file_text(filename) or '%sinclude%s' % tuple(self.delimiters)
 
         # Create out nodes list to send to the parent
         super_nodes = []
@@ -465,16 +486,17 @@ class TemplateParser(object):
         super_nodes.extend(self.super_nodes)
 
         t = TemplateParser(text,
-                    name         = filename,
-                    context      = self.context,
-                    path         = self.path,
-                    writer       = self.writer,
-                    delimiters   = self.delimiters,
-                    _super_nodes = super_nodes)
+                           name=filename,
+                           context=self.context,
+                           path=self.path,
+                           writer=self.writer,
+                           delimiters=self.delimiters,
+                           _super_nodes=super_nodes)
 
         # Make a temporary buffer that is unique for parent
         # template.
-        buf = BlockNode(name='__include__' + filename, delimiters=self.delimiters)
+        buf = BlockNode(
+            name='__include__' + filename, delimiters=self.delimiters)
         pre = []
 
         # Iterate through each of our nodes
@@ -504,7 +526,7 @@ class TemplateParser(object):
         self.content.nodes = []
 
         t_content = t.content
-        
+
         # Set our include, unique by filename
         t_content.blocks['__include__' + filename] = buf
 
@@ -548,8 +570,9 @@ class TemplateParser(object):
                 if in_tag:
                     line = i
 
-                    # Get rid of '{{' and '}}'
-                    line = line[2:-2].strip()
+                    # Get rid of delimiters
+                    line = line[len(self.delimiters[0]): \
+                                    -len(self.delimiters[1])].strip()
 
                     # This is bad juju, but let's do it anyway
                     if not line:
@@ -601,22 +624,22 @@ class TemplateParser(object):
                         # You can define custom names such as
                         # '{{<<variable}}' which could potentially
                         # write unescaped version of the variable.
-                        self.lexers[name](parser    = self,
-                                          value     = value,
-                                          top       = top,
-                                          stack     = stack)
+                        self.lexers[name](parser=self,
+                                          value=value,
+                                          top=top,
+                                          stack=stack)
 
                     elif name == '=':
                         # So we have a variable to insert into
                         # the template
                         buf = "\n%s(%s)" % (self.writer, value)
-                        top.append(Node(buf, pre_extend = pre_extend))
+                        top.append(Node(buf, pre_extend=pre_extend))
 
                     elif name == 'block' and not value.startswith('='):
                         # Make a new node with name.
-                        node = BlockNode(name = value.strip(),
-                                         pre_extend = pre_extend,
-                                         delimiters = self.delimiters)
+                        node = BlockNode(name=value.strip(),
+                                         pre_extend=pre_extend,
+                                         delimiters=self.delimiters)
 
                         # Append this node to our active node
                         top.append(node)
@@ -646,8 +669,8 @@ class TemplateParser(object):
                             target_node = top.name
 
                         # Create a SuperNode instance
-                        node = SuperNode(name = target_node,
-                                            pre_extend = pre_extend)
+                        node = SuperNode(name=target_node,
+                                         pre_extend=pre_extend)
 
                         # Add this to our list to be taken care of
                         self.super_nodes.append(node)
@@ -663,9 +686,10 @@ class TemplateParser(object):
                         # Otherwise, make a temporary include node
                         # That the child node will know to hook into.
                         else:
-                            include_node = BlockNode(name = '__include__' + self.name,
-                                                     pre_extend = pre_extend,
-                                                     delimiters = self.delimiters)
+                            include_node = BlockNode(
+                                name='__include__' + self.name,
+                                pre_extend=pre_extend,
+                                delimiters=self.delimiters)
                             top.append(include_node)
 
                     elif name == 'extend' and not value.startswith('='):
@@ -697,21 +721,22 @@ class TemplateParser(object):
                                 if token.startswith('='):
                                     if token.endswith('\\'):
                                         continuation = True
-                                        tokens[k] = "\n%s(%s" % (self.writer, token[1:].strip())
+                                        tokens[k] = "\n%s(%s" % (
+                                            self.writer, token[1:].strip())
                                     else:
-                                        tokens[k] = "\n%s(%s)" % (self.writer, token[1:].strip())
+                                        tokens[k] = "\n%s(%s)" % (
+                                            self.writer, token[1:].strip())
                                 elif continuation:
                                     tokens[k] += ')'
                                     continuation = False
 
-
                             buf = "\n%s" % '\n'.join(tokens)
-                            top.append(Node(buf, pre_extend = pre_extend))
+                            top.append(Node(buf, pre_extend=pre_extend))
 
                 else:
                     # It is HTML so just include it.
                     buf = "\n%s(%r, escape=False)" % (self.writer, i)
-                    top.append(Node(buf, pre_extend = pre_extend))
+                    top.append(Node(buf, pre_extend=pre_extend))
 
             # Remember: tag, not tag, tag, not tag
             in_tag = not in_tag
@@ -740,16 +765,21 @@ class TemplateParser(object):
             self.extend(extend)
 
 # We need this for integration with gluon
+
+
 def parse_template(filename,
-                   path    = 'views/',
-                   context = dict(),
-                   lexers  = {},
-                   delimiters = ('{{','}}')
+                   path='views/',
+                   context=dict(),
+                   lexers={},
+                   delimiters=('{{', '}}')
                    ):
     """
-    filename can be a view filename in the views folder or an input stream
-    path is the path of a views folder
-    context is a dictionary of symbols used to render the template
+    Args:
+        filename: can be a view filename in the views folder or an input stream
+        path: is the path of a views folder
+        context: is a dictionary of symbols used to render the template
+        lexers: dict of custom lexers to use
+        delimiters: opening and closing tags
     """
 
     # First, if we have a str try to open the file
@@ -766,6 +796,7 @@ def parse_template(filename,
     # Use the file contents to get a parsed template and return it.
     return str(TemplateParser(text, context=context, path=path, lexers=lexers, delimiters=delimiters))
 
+
 def get_parsed(text):
     """
     Returns the indented python code of text. Useful for unit testing.
@@ -773,13 +804,15 @@ def get_parsed(text):
     """
     return str(TemplateParser(text))
 
+
 class DummyResponse():
     def __init__(self):
-        self.body = cStringIO.StringIO()
+        self.body = StringIO.StringIO()
+
     def write(self, data, escape=True):
         if not escape:
             self.body.write(str(data))
-        elif hasattr(data,'xml') and callable(data.xml):
+        elif hasattr(data, 'xml') and callable(data.xml):
             self.body.write(data.xml())
         else:
             # make it a string
@@ -787,53 +820,72 @@ class DummyResponse():
                 data = str(data)
             elif isinstance(data, unicode):
                 data = data.encode('utf8', 'xmlcharrefreplace')
-            data = cgi.escape(data, True).replace("'","&#x27;")
+            data = cgi.escape(data, True).replace("'", "&#x27;")
             self.body.write(data)
 
+
 class NOESCAPE():
     """
     A little helper to avoid escaping.
     """
     def __init__(self, text):
         self.text = text
+
     def xml(self):
         return self.text
 
 # And this is a generic render function.
 # Here for integration with gluon.
-def render(content = "hello world",
-           stream = None,
-           filename = None,
-           path = None,
-           context = {},
-           lexers  = {},
-           delimiters = ('{{','}}')
+
+
+def render(content="hello world",
+           stream=None,
+           filename=None,
+           path=None,
+           context={},
+           lexers={},
+           delimiters=('{{', '}}'),
+           writer='response.write'
            ):
     """
-    >>> render()
-    'hello world'
-    >>> render(content='abc')
-    'abc'
-    >>> render(content='abc\\'')
-    "abc'"
-    >>> render(content='a"\\'bc')
-    'a"\\'bc'
-    >>> render(content='a\\nbc')
-    'a\\nbc'
-    >>> render(content='a"bcd"e')
-    'a"bcd"e'
-    >>> render(content="'''a\\nc'''")
-    "'''a\\nc'''"
-    >>> render(content="'''a\\'c'''")
-    "'''a\'c'''"
-    >>> render(content='{{for i in range(a):}}{{=i}}<br />{{pass}}', context=dict(a=5))
-    '0<br />1<br />2<br />3<br />4<br />'
-    >>> render(content='{%for i in range(a):%}{%=i%}<br />{%pass%}', context=dict(a=5),delimiters=('{%','%}'))
-    '0<br />1<br />2<br />3<br />4<br />'
-    >>> render(content="{{='''hello\\nworld'''}}")
-    'hello\\nworld'
-    >>> render(content='{{for i in range(3):\\n=i\\npass}}')
-    '012'
+    Generic render function
+
+    Args:
+        content: default content
+        stream: file-like obj to read template from
+        filename: where to find template
+        path: base path for templates
+        context: env
+        lexers: custom lexers to use
+        delimiters: opening and closing tags
+        writer: where to inject the resulting stream
+
+    Example::
+        >>> render()
+        'hello world'
+        >>> render(content='abc')
+        'abc'
+        >>> render(content="abc'")
+        "abc'"
+        >>> render(content=''''a"'bc''')
+        'a"'bc'
+        >>> render(content='a\\nbc')
+        'a\\nbc'
+        >>> render(content='a"bcd"e')
+        'a"bcd"e'
+        >>> render(content="'''a\\nc'''")
+        "'''a\\nc'''"
+        >>> render(content="'''a\\'c'''")
+        "'''a\'c'''"
+        >>> render(content='{{for i in range(a):}}{{=i}}<br />{{pass}}', context=dict(a=5))
+        '0<br />1<br />2<br />3<br />4<br />'
+        >>> render(content='{%for i in range(a):%}{%=i%}<br />{%pass%}', context=dict(a=5),delimiters=('{%','%}'))
+        '0<br />1<br />2<br />3<br />4<br />'
+        >>> render(content="{{='''hello\\nworld'''}}")
+        'hello\\nworld'
+        >>> render(content='{{for i in range(3):\\n=i\\npass}}')
+        '012'
+
     """
     # here to avoid circular Imports
     try:
@@ -849,14 +901,14 @@ def render(content = "hello world",
     # save current response class
     if context and 'response' in context:
         old_response_body = context['response'].body
-        context['response'].body = cStringIO.StringIO()
+        context['response'].body = StringIO.StringIO()
     else:
         old_response_body = None
         context['response'] = Response()
 
     # If we don't have anything to render, why bother?
     if not content and not stream and not filename:
-        raise SyntaxError, "Must specify a stream or filename or content"
+        raise SyntaxError("Must specify a stream or filename or content")
 
     # Here for legacy purposes, probably can be reduced to
     # something more simple.
@@ -866,10 +918,11 @@ def render(content = "hello world",
             stream = open(filename, 'rb')
             close_stream = True
         elif content:
-            stream = cStringIO.StringIO(content)
+            stream = StringIO.StringIO(content)
 
     # Execute the template.
-    code = str(TemplateParser(stream.read(), context=context, path=path, lexers=lexers, delimiters=delimiters))
+    code = str(TemplateParser(stream.read(
+    ), context=context, path=path, lexers=lexers, delimiters=delimiters, writer=writer))
     try:
         exec(code) in context
     except Exception:
@@ -889,10 +942,3 @@ def render(content = "hello world",
 if __name__ == '__main__':
     import doctest
     doctest.testmod()
-
-
-
-
-
-
-
