@@ -2,9 +2,9 @@
 # -*- coding: utf-8 -*-
 
 """
-This file is part of the web2py Web Framework
-Copyrighted by Massimo Di Pierro <mdipierro@cs.depaul.edu>
-License: LGPLv3 (http://www.gnu.org/licenses/lgpl.html)
+| This file is part of the web2py Web Framework
+| Copyrighted by Massimo Di Pierro <mdipierro@cs.depaul.edu>
+| License: LGPLv3 (http://www.gnu.org/licenses/lgpl.html)
 """
 
 from SimpleXMLRPCServer import SimpleXMLRPCDispatcher
@@ -19,10 +19,3 @@ def handler(request, response, methods):
     response.headers['Content-Type'] = 'text/xml'
     dispatch = getattr(dispatcher, '_dispatch', None)
     return dispatcher._marshaled_dispatch(request.body.read(), dispatch)
-
-
-
-
-
-
-
