@@ -1,4 +1,6 @@
-import sys, glob
+import sys
+import glob
+
 
 def read_fileb(filename, mode='rb'):
     f = open(filename, mode)
@@ -7,6 +9,7 @@ def read_fileb(filename, mode='rb'):
     finally:
         f.close()
 
+
 def write_fileb(filename, value, mode='wb'):
     f = open(filename, mode)
     try:
@@ -17,8 +20,8 @@ def write_fileb(filename, value, mode='wb'):
 for filename in glob.glob(sys.argv[1]):
     data1 = read_fileb(filename)
     write_fileb(filename + '.bak2', data1)
-    data2lines = read_fileb(filename).split('\n')
-    data2 = '\n'.join([line.rstrip().replace('\t','    '*2) for line in data2lines])+'\n'
+    data2lines = read_fileb(filename).strip().split('\n')
+    data2 = '\n'.join([line.rstrip(
+    ).replace('\t', '    ' * 2) for line in data2lines]) + '\n'
     write_fileb(filename, data2)
-    print filename, len(data1)-len(data2)
-
+    print filename, len(data1) - len(data2)
