@@ -15,7 +15,7 @@ SLEEP_MINUTES = 5
 
 errors_path = os.path.join(request.folder, 'errors')
 try:
-    db_string = open(os.path.join(request.folder, 'private', 'ticket_storage.txt')).read().replace('\r','').replace('\n','').strip()
+    db_string = open(os.path.join(request.folder, 'private', 'ticket_storage.txt')).read().replace('\r', '').replace('\n', '').strip()
 except:
     db_string = 'sqlite://storage.db'
 
@@ -23,7 +23,8 @@ db_path = os.path.join(request.folder, 'databases')
 
 tk_db = DAL(db_string, folder=db_path, auto_import=True)
 ts = TicketStorage(db=tk_db)
-tk_table = ts._get_table(db=tk_db, tablename=ts.tablename, app=request.application)
+tk_table = ts._get_table(
+    db=tk_db, tablename=ts.tablename, app=request.application)
 
 
 hashes = {}
@@ -46,6 +47,5 @@ while 1:
                         )
         tk_db.commit()
         os.unlink(filename)
-        
-    time.sleep(SLEEP_MINUTES * 60)
 
+    time.sleep(SLEEP_MINUTES * 60)
